<?php
/**
 * Customizer functionality
 *
 * @package Signify
 */

/**
 * Sets up the WordPress core custom header and custom background features.
 *
 * @since 1.0.0
 *
 * @see signify_header_style()
 */
function signify_custom_header_and_background() {
	$color_scheme             = signify_get_color_scheme();
	$default_background_color = trim( $color_scheme[0], '#' );
	$default_text_color       = trim( $color_scheme[1], '#' );

	/**
	 * Filter the arguments used when adding 'custom-background' support in Signify.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args {
	 *     An array of custom-background support arguments.
	 *
	 *     @type string $default-color Default color of the background.
	 * }
	 */
	add_theme_support( 'custom-background', apply_filters( 'signify_custom_background_args', array(
		'default-color' => $default_background_color,
	) ) );

	/**
	 * Filter the arguments used when adding 'custom-header' support in Signify.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args {
	 *     An array of custom-header support arguments.
	 *
	 *     @type string $default-text-color Default color of the header text.
	 *     @type int      $width            Width in pixels of the custom header image. Default 1200.
	 *     @type int      $height           Height in pixels of the custom header image. Default 280.
	 *     @type bool     $flex-height      Whether to allow flexible-height header images. Default true.
	 *     @type callable $wp-head-callback Callback function used to style the header image and text
	 *                                      displayed on the blog.
	 * }
	 */
	add_theme_support( 'custom-header', apply_filters( 'signify_custom_header_args', array(
		'default-image'      	 => get_parent_theme_file_uri( '/images/header-image.jpg' ),
		'default-text-color'     => $default_text_color,
		'width'                  => 1920,
		'height'                 => 1080,
		'flex-height'            => true,
		'flex-height'            => true,
		'wp-head-callback'       => 'signify_header_style',
		'video'                  => true,
	) ) );

	register_default_headers( array(
		'default-image' => array(
			'url'           => '%s/images/header-image.jpg',
			'thumbnail_url' => '%s/images/header-image-275x155.jpg',
			'description'   => esc_html__( 'Default Header Image', 'signify-pro' ),
		),
		'dark-image' => array(
			'url'           => '%s/images/header-image-dark.jpg',
			'thumbnail_url' => '%s/images/header-image-dark-275x155.jpg',
			'description'   => esc_html__( 'Dark Color Scheme Header Image', 'signify-pro' ),
		),
		'education-image' => array(
			'url'           => '%s/images/header-image-education.jpg',
			'thumbnail_url' => '%s/images/header-image-education-275x155.jpg',
			'description'   => esc_html__( 'Education Scheme Header Image', 'signify-pro' ),
		),
		'wedding-image' => array(
			'url'           => '%s/images/header-image-wedding.jpg',
			'thumbnail_url' => '%s/images/header-image-wedding-275x155.jpg',
			'description'   => esc_html__( 'Wedding Scheme Header Image', 'signify-pro' ),
		),
	) );
}
add_action( 'after_setup_theme', 'signify_custom_header_and_background' );

function signify_color_options() {
	//Color Scheme
	$default_color = signify_get_color_scheme();

	// We do not add Background Color and Header Text Color here as if comes from WordPress Core
	return apply_filters( 'signify_color_options', array(
			'page_background_color'           => array(
				'label'   => esc_html__( 'Page Background Color', 'signify-pro' ),
				'default' => $default_color[2],
			),
			'secondary_background_color' => array(
				'label'   => esc_html__( 'Secondary Background Color', 'signify-pro' ),
				'default' => $default_color[3],
			),
			'main_text_color'                 => array(
				'label'   => esc_html__( 'Main Text Color', 'signify-pro' ),
				'default' => $default_color[4],
			),
			'absolute_header_menu_text_color'                 => array(
				'label'   => esc_html__( 'Absolute Header Menu Text Color', 'signify-pro' ),
				'default' => $default_color[5],
			),
			'absolute_header_text_color'                 => array(
				'label'   => esc_html__( 'Absolute Header Text Color', 'signify-pro' ),
				'default' => $default_color[6],
			),
			'custom_header_slider_color'                 => array(
				'label'   => esc_html__( 'Custom Header and Slider Color', 'signify-pro' ),
				'default' => $default_color[7],
			),
			'headline_text_color'         => array(
				'label'   => esc_html__( 'Headline Text Color', 'signify-pro' ),
				'default' => $default_color[8],
			),
			'link_color'                      => array(
				'label'   => esc_html__( 'Link Color', 'signify-pro' ),
				'default' => $default_color[9],
			),
			'page_post_content_link_color'                      => array(
				'label'   => esc_html__( 'Page Post Content Link Color', 'signify-pro' ),
				'default' => $default_color[10],
			),
			'link_hover_color'                => array(
				'label'   => esc_html__( 'Link Hover Color', 'signify-pro' ),
				'default' => $default_color[11],
			),
			'secondary_link_color'                      => array(
				'label'   => esc_html__( 'Secondary Link Color', 'signify-pro' ),
				'default' => $default_color[12],
			),
			'button_background_color'                         => array(
				'label'   => esc_html__( 'Button Background Color', 'signify-pro' ),
				'default' => $default_color[13],
			),
			'button_text_color'               => array(
				'label'   => esc_html__( 'Button Text Color', 'signify-pro' ),
				'default' => $default_color[14],
			),
			'button_hover_text_color'         => array(
				'label'   => esc_html__( 'Button Hover Text Color', 'signify-pro' ),
				'default' => $default_color[15],
			),
			'button_background_hover_color'                         => array(
				'label'   => esc_html__( 'Button Hover Background Color', 'signify-pro' ),
				'default' => $default_color[16],
			),
			'border_color'                => array(
				'label'   => esc_html__( 'Border Color', 'signify-pro' ),
				'default' => $default_color[17],
			),
			'textcolor_with_background'                    => array(
				'label'   => esc_html__( 'Text Color With Background', 'signify-pro' ),
				'default' => $default_color[18],
			),
		)
	);
}

/**
 * Customize video play/pause button in the custom header.
 *
 * @param array $settings header video settings.
 */
function signify_video_controls( $settings ) {
	$settings['l10n']['play'] = '<span class="screen-reader-text">' . esc_html__( 'Play background video', 'signify-pro' ) . '</span>';
	$settings['l10n']['pause'] = '<span class="screen-reader-text">' . esc_html__( 'Pause background video', 'signify-pro' ) . '</span>';
	return $settings;
}
add_filter( 'header_video_settings', 'signify_video_controls' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @since 1.0.0
 * @see signify_customize_register()
 *
 * @return void
 */
function signify_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @since 1.0.0
 * @see signify_customize_register()
 *
 * @return void
 */
function signify_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Registers color schemes for Signify.
 *
 * Can be filtered with {@see 'signify_color_schemes'}.
 *
 * The order of colors in a colors array:
 * 1. Background Color
 * 2. Header Text Color
 * 3. Page Background Color
 * 4. Secondary Background Color
 * 5. Main Text Color
 * 6. Absolute Header Menu Text Color
 * 7. Absolute Header Text Color
 * 8. Custom Header and Slider Color
 * 9. Headline Text Color
 * 10. Link Color
 * 11. Page Post Content Link Color
 * 12. Link Hover Color
 * 13. Secondary Link Color
 * 14. Button Background Color
 * 15. Button Text Color
 * 16. Button Hover Text Color
 * 17. Button Hover Background Color
 * 18. Border Color
 * 19. Text Color With Background

 *
 * @since 1.0.0
 *
 * @return array An associative array of color scheme options.
 */
function signify_get_color_schemes() {
	/**
	 * Filter the color schemes registered for use with Signify.
	 *
	 * The default schemes include 'default', 'dark', 'gray', 'red', and 'yellow'.
	 *
	 * @since 1.0.0
	 *
	 * @param array $schemes {
	 *     Associative array of color schemes data.
	 *
	 *     @type array $slug {
	 *         Associative array of information for setting up the color scheme.
	 *
	 *         @type string $label  Color scheme label.
	 *         @type array  $colors HEX codes for default colors prepended with a hash symbol ('#').
	 *                              Colors are defined in the following order: Main background, page
	 *                              background, link, main text, secondary text.
	 *     }
	 * }
	 */
	return apply_filters( 'signify_color_schemes', array(
		'default' => array(
			'label'  => esc_html__( 'Default', 'signify-pro' ),
			'colors' => array(
				'#ffffff', /* Background Color */
				'#000000', /* Header Text Color */
				'#ffffff', /* Page Background Color */
				'#f9f9f9', /* Secondary Background Color */
				'#000000', /* Main Text Color */
				'#ffffff', /* Absolute Header Menu Text Color */
				'#ffffff', /* Absolute Header Text Color */
				'#111111', /* Custom Header and Slider Color */
				'#000000', /* Headline Text Color */
				'#111111', /* Link Color */
				'#f5808c', /* Page Post Content Link Color */
				'#f5808c', /* Link Hover Color */
				'#777777', /* Secondary Link Color */
				'#f5808c', /* Button Background Color */
				'#ffffff', /* Button Text Color */
				'#000000', /* Button Hover Text Color */
				'#ffffff', /* Button Hover Background Color */
				'#e6e6e6', /* Border Color */
				'#ffffff', /* Text Color With Background */
			),
		),
		'dark' => array( /* Dark */
			'label'  => esc_html__( 'Dark', 'signify-pro' ),
			'colors' => array(
				'#000000', /* Background Color */
				'#ffffff', /* Header Text Color */
				'#000000', /* Page Background Color */
				'#222222', /* Secondary Background Color */
				'#999999', /* Main Text Color */
				'#ffffff', /* Absolute Header Menu Text Color */
				'#ffffff', /* Absolute Header Text Color */
				'#ffffff', /* Custom Header and Slider Color */
				'#ffffff', /* Headline Text Color */
				'#ffffff', /* Link Color */
				'#db4f3d', /* Page Post Content Link Color */
				'#db4f3d', /* Link Hover Color */
				'#999999', /* Secondary Link Color */
				'#db4f3d', /* Button Background Color */
				'#ffffff', /* Button Text Color */
				'#000000', /* Button Hover Text Color */
				'#ffffff', /* Button Hover Background Color */
				'#2f2f2f', /* Border Color */
				'#ffffff', /* Text Color With Background */
			),
		),
		'wedding' => array(
			'label'  => esc_html__( 'Wedding', 'signify-pro' ),
			'colors' => array(
				'#ffffff', /* Background Color */
				'#000000', /* Header Text Color */
				'#ffffff', /* Page Background Color */
				'#f9f9f9', /* Secondary Background Color */
				'#000000', /* Main Text Color */
				'#ffffff', /* Absolute Header Menu Text Color */
				'#ffffff', /* Absolute Header Text Color */
				'#ffffff', /* Custom Header and Slider Color */
				'#000000', /* Headline Text Color */
				'#111111', /* Link Color */
				'#f5808c', /* Page Post Content Link Color */
				'#f5808c', /* Link Hover Color */
				'#777777', /* Secondary Link Color */
				'#f5808c', /* Button Background Color */
				'#ffffff', /* Button Text Color */
				'#000000', /* Button Hover Text Color */
				'#ffffff', /* Button Hover Background Color */
				'#e6e6e6', /* Border Color */
				'#ffffff', /* Text Color With Background */
			),
		),
		'education' => array(
			'label'  => esc_html__( 'Education', 'signify-pro' ),
			'colors' => array(
				'#ffffff', /* Background Color */
				'#000000', /* Header Text Color */
				'#ffffff', /* Page Background Color */
				'#f9f9f9', /* Secondary Background Color */
				'#000000', /* Main Text Color */
				'#ffffff', /* Absolute Header Menu Text Color */
				'#ffffff', /* Absolute Header Text Color */
				'#111111', /* Custom Header and Slider Color */
				'#000000', /* Headline Text Color */
				'#111111', /* Link Color */
				'#008ec2', /* Page Post Content Link Color */
				'#008ec2', /* Link Hover Color */
				'#777777', /* Secondary Link Color */
				'#008ec2', /* Button Background Color */
				'#ffffff', /* Button Text Color */
				'#000000', /* Button Hover Text Color */
				'#ffffff', /* Button Hover Background Color */
				'#e6e6e6', /* Border Color */
				'#ffffff', /* Text Color With Background */
			),
		),
	) );
}

if ( ! function_exists( 'signify_get_color_scheme' ) ) :
/**
 * Retrieves the current Signify color scheme.
 *
 * Create your own signify_get_color_scheme() function to override in a child theme.
 *
 * @since 1.0.0
 *
 * @return array An associative array of either the current or default color scheme HEX values.
 */
function signify_get_color_scheme() {
	$color_scheme_option = get_theme_mod( 'color_scheme', 'default' );
	$color_schemes       = signify_get_color_schemes();

	if ( array_key_exists( $color_scheme_option, $color_schemes ) ) {
		return $color_schemes[ $color_scheme_option ]['colors'];
	}

	return $color_schemes['default']['colors'];
}
endif; // signify_get_color_scheme

if ( ! function_exists( 'signify_get_color_scheme_choices' ) ) :
/**
 * Retrieves an array of color scheme choices registered for Signify.
 *
 * Create your own signify_get_color_scheme_choices() function to override
 * in a child theme.
 *
 * @since 1.0.0
 *
 * @return array Array of color schemes.
 */
function signify_get_color_scheme_choices() {
	$color_schemes                = signify_get_color_schemes();
	$color_scheme_control_options = array();

	foreach ( $color_schemes as $color_scheme => $value ) {
		$color_scheme_control_options[ $color_scheme ] = $value['label'];
	}

	return $color_scheme_control_options;
}
endif; // signify_get_color_scheme_choices


if ( ! function_exists( 'signify_sanitize_color_scheme' ) ) :
/**
 * Handles sanitization for Signify color schemes.
 *
 * Create your own signify_sanitize_color_scheme() function to override
 * in a child theme.
 *
 * @since 1.0.0
 *
 * @param string $value Color scheme name value.
 * @return string Color scheme name.
 */
function signify_sanitize_color_scheme( $value ) {
	$color_schemes = signify_get_color_scheme_choices();

	if ( ! array_key_exists( $value, $color_schemes ) ) {
		return 'default';
	}

	return $value;
}
endif; // signify_sanitize_color_scheme

/**
 * Enqueues front-end CSS for color scheme.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_color_scheme_css() {
	$color_scheme_option = get_theme_mod( 'color_scheme', 'default' );

	// Don't do anything if the default color scheme is selected.
	if ( 'default' === $color_scheme_option ) {
		return;
	}

	$color_scheme = signify_get_color_scheme();

	// If we get this far, we have a custom color scheme.
	$colors = array(
		'background_color'                                    => $color_scheme[0],
		'header_textcolor'                                    => $color_scheme[1],
		'page_background_color'                               => $color_scheme[2],
		'secondary_background_color'                          => $color_scheme[3],
		'main_text_color'                                     => $color_scheme[4],
		'absolute_header_menu_text_color'                     => $color_scheme[5],
		'absolute_header_text_color'                          => $color_scheme[6],
		'custom_header_slider_color'                          => $color_scheme[7],
		'headline_text_color'                                 => $color_scheme[8],
		'link_color'                                          => $color_scheme[9],
		'page_post_content_link_color'                        => $color_scheme[10],
		'link_hover_color'                                    => $color_scheme[11],
		'secondary_link_color'                                => $color_scheme[12],
		'button_background_color'                       	  => $color_scheme[13],
		'button_text_color'                                   => $color_scheme[14],
		'button_hover_text_color'                             => $color_scheme[15],
		'button_background_hover_color'                       => $color_scheme[16],
		'border_color'                                        => $color_scheme[17],
		'textcolor_with_background'                           => $color_scheme[18],
	);

	$color_scheme_css = signify_get_color_scheme_css( $colors );

	wp_add_inline_style( 'signify-block-style', $color_scheme_css );
}
add_action( 'wp_enqueue_scripts', 'signify_color_scheme_css' );

/**
 * Binds the JS listener to make Customizer color_scheme control.
 *
 * Passes color scheme data as colorScheme global.
 *
 * @since 1.0.0
 */
function signify_customize_control_js() {
	$min  = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	wp_enqueue_script( 'signify-color-scheme-control', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'js/color-scheme-control' . $min . '.js', array( 'customize-controls', 'iris', 'underscore', 'wp-util' ), '20170816', true );

	$colors['colorScheme'] = signify_get_color_schemes();

	$color_options = signify_color_options();

	// Add background color and header text color index values
	$color_options = array_merge( array( 'background_color', 'header_textcolor' ), array_keys( $color_options ) );

	$colors['colorOptions'] = $color_options;

	wp_localize_script( 'signify-color-scheme-control', 'signifyColorMain', $colors );

	wp_enqueue_script( 'signify-custom-controls', trailingslashit( esc_url( get_template_directory_uri() ) ) . 'js/customize-custom-controls' . $min . '.js', array( 'jquery-ui-sortable' ), '20180802', true );

	wp_enqueue_style( 'signify-custom-controls-css', trailingslashit( esc_url( get_template_directory_uri() ) ) . 'css/customizer.css' );

}
add_action( 'customize_controls_enqueue_scripts', 'signify_customize_control_js' );

/**
 * Returns CSS for the color schemes.
 *
 * @since 1.0.0
 *
 * @param array $colors Color scheme colors.
 * @return string Color scheme CSS.
 */
function signify_get_color_scheme_css( $colors ) {
	$colors = wp_parse_args( $colors, array(
		'background_color'                                    => '',
		'header_textcolor'                                    => '',
		'page_background_color'                               => '',
		'secondary_background_color'                          => '',
		'main_text_color'                                     => '',
		'absolute_header_menu_text_color'                     => '',
		'absolute_header_text_color'                          => '',
		'custom_header_slider_color'                          => '',
		'headline_text_color'                                 => '',
		'link_color'                                          => '',
		'page_post_content_link_color'                        => '',
		'link_hover_color'                                    => '',
		'secondary_link_color'                                => '',
		'button_background_color'                             => '',
		'button_text_color'                                   => '',
		'button_hover_text_color'                             => '',
		'button_background_hover_color'                       => '',
		'border_color'                                        => '',
		'textcolor_with_background'                           => '',

	) );

	return <<<CSS
	/* Color Scheme */

	/* Background Color */
	body {
		background-color: {$colors['background_color']};
	}

	/* Page Background Color */
	.screen-reader-text:focus,
	.boxed-layout .site,
	.ui-state-active,
	.section:nth-child(odd).hero-section .content-wrapper,
	.section:nth-child(odd) .events-content-wrapper .hentry-inner,
	.ui-widget-content .ui-state-active,
	.ui-widget-header .ui-state-active,
	.onsale,
	#contact-section,
	#contact-section .contact-content-wrapper,
	.comments-area textyarea,
	.comments-area input:not([type="submit"]),
	.comment-form input:not([type="submit"]),
	.comment-form textarea,
	.site-header-menu input[type="search"].search-field,
	.widget input[type="search"].search-field,
	.widget input:not([type="submit"]),
	.widget textarea,
	.section:nth-child(even) + #contact-section .section-content-wrapper input:not([type="submit"]),
	.section:nth-child(even) + #contact-section .section-content-wrapper textarea,
	#search-top-container input[type="search"].search-field,
	.section:nth-child(even).promotion-section.content-frame .entry-container-frame {
		background-color: {$colors['page_background_color']};
	}

	.timeline-section .hentry .hentry-inner:before {
	    border-color: {$colors['page_background_color']};
	}

	.wp-playlist-light,
	#sticky-playlist-section,
	#sticky-playlist-section .wp-playlist-tracks {
	    background-color: {$colors['page_background_color']};
	}

	/* Secondary Background Color */
	#colophon .widget-area,
	body.boxed-layout,
	.section:nth-child(odd),
	.section:nth-child(even).hero-section .content-wrapper,
	.section:nth-child(even) .events-content-wrapper .hentry-inner,
	.section:nth-child(even) + #contact-section .section-content-wrapper,
	.mejs-controls .mejs-horizontal-volume-slider .mejs-horizontal-volume-total,
	.mejs-controls .mejs-time-rail .mejs-time-total,
	.signify-mejs-container.mejs-container .mejs-controls .mejs-time-rail .mejs-time-loaded,
	.signify-mejs-container.mejs-container .mejs-controls .mejs-time-rail .mejs-time-float,
	ins,
	.sidebar .widget-wrap,
	#primary-search-wrapper .menu-inside-wrapper,
	.menu-inside-wrapper,
	.mobile-social-search,
	#footer-newsletter,
	mark,
	ins,
	.custom-header,
	ul.tabs.wc-tabs li.active a,
	.woocommerce-Tabs-panel,
	.shop_table thead th,
	ul.wc_payment_methods.payment_methods.methods li,
	.comment-respond,
	.widget_shopping_cart,
	pre,
	.widget .ui-tabs .ui-tabs-panel,
	select,
	.select2-container--default .select2-selection--single,
	input[type="text"],
	input[type="email"],
	input[type="url"],
	input[type="password"],
	input[type="search"],
	input[type="number"],
	input[type="tel"],
	input[type="range"],
	input[type="date"],
	input[type="month"],
	input[type="week"],
	input[type="time"],
	input[type="datetime"],
	input[type="datetime-local"],
	input[type="color"],
	textarea,
	.header-top-bar,
	.comment-list .comment .comment-container,
	.promotion-section.content-frame .entry-container-frame:after {
		background-color: {$colors['secondary_background_color']};
	}

	#sticky-playlist-section,
	.comment-list .comment-author:before {
	    border-color: {$colors['secondary_background_color']};
	}

	@media screen and (min-width: 1024px) {
	    .navigation-classic .site-header .sub-menu,
	    .navigation-classic .site-header .children,
	    .site-header .header-top-bar .sub-menu,
    	.site-header .header-top-bar .children {
	        background-color: {$colors['secondary_background_color']};
	    }
	}

	/* Main Text Color */
	body,
	input,
	select,
	optgroup,
	textarea,
	table a,
	input::placeholder,
	input[type="text"],
	input[type="email"],
	input[type="url"],
	input[type="password"],
	input[type="search"],
	input[type="number"],
	input[type="tel"],
	input[type="range"],
	input[type="date"],
	input[type="month"],
	input[type="week"],
	input[type="time"],
	input[type="datetime"],
	input[type="datetime-local"],
	input[type="color"],
	.singular-content-wrap .entry-content a:not(.more-link):not(.button):not(button):hover,
	.singular-content-wrap .entry-content a:not(.more-link):not(.button):not(button):focus,
	.singular-content-wrap .entry-summary a:not(.more-link):not(.button):not(button):hover,
	.singular-content-wrap .entry-summary a:not(.more-link):not(.button):not(button):focus,
	.has-background-image.events-section .hentry .event-list-description .entry-summary,
	.has-background-image.events-section .hentry .event-list-description .entry-content,
	#search-top-container .search-submit {
		color: {$colors['main_text_color']};
	}

	/* Header Text Color */
	.site-title a,
	.site-description {
		color: {$colors['header_textcolor']};
	}

	/* Absolute Header Menu Text Color */
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .menu-toggle,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .menu-label,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .menu-toggle,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .menu-label {
	    color: {$colors['absolute_header_menu_text_color']};
	}

	@media screen and (min-width: 1200px) {
	    body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media.navigation-classic .site-header-main .main-navigation > .nav-menu > li > a,
	    body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home.navigation-classic .site-header-main .main-navigation > .nav-menu > li > a {
	        color: {$colors['absolute_header_menu_text_color']};
	    }
	}


	@media screen and (min-width: 767px) {
	    body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .cart-contents,
	    body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .cart-contents {
	        color: {$colors['absolute_header_menu_text_color']};
	    }
	}

	/* Absolute Header Text Color */

	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-title a,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-description,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-title a,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-description {
	    color: {$colors['absolute_header_text_color']};
	}

	/* Custom Header and Slider Color */
	.header-media-tagline,
	.custom-header .section-title,
	.custom-header .site-header-text,
	.feature-slider-wrapper .entry-container .entry-title,
	.feature-slider-wrapper .entry-container .entry-title span,
	.feature-slider-wrapper .entry-container .entry-summary,
	.feature-slider-wrapper .entry-container .entry-content {
	    color: {$colors['custom_header_slider_color']};
	}

	/* Headline Text Color */
	h1,
	h2,
	h3,
	h4,
	h5,
	h6,
	.section-title,
	.vcard,
	.has-background-image.events-section .hentry .entry-title a,
	.has-background-image.events-section .hentry .entry-title,
	.has-background-image.events-section.style-two .hentry .entry-meta a,
	#featured-content-section .section-content-wrapper .hentry .more-link,
	#featured-content-section .section-content-wrapper .hentry .button,
	#featured-content-section .section-content-wrapper .hentry button,
	.wpcf7 input[type=submit],
	.position,
	.section-description-wrapper,
	.section-title-wrapper+.section-description,
	.section-title+.section-description,
	.section-title-wrapper+.section-subtitle,
	.section-heading-wrapper>.section-description,
	.section-title+.section-description,
	.drop-cap:first-letter,
	#featured-content-section .entry-header .entry-meta > span a:hover,
	#featured-content-section .entry-header .entry-meta > span a:focus,
	.product .woocommerce-Price-amount:hover,
	.product .woocommerce-Price-amount:focus,
	#stats-section .entry-title a:hover,
	#stats-section .entry-title a:focus,
	.product-container a.button,
	.author-name,
	.comment-reply-link,
	.author-title,
	.stats-section .entry-summary .more-link,
	.stats-section .entry-content .more-link,
	.comment-respond .comment-form p label,
	blockquote,
	.woocommerce .products .product-container .added_to_cart,
	.signify-mejs-container.mejs-container button,
	.archive-posts-wrapper .hentry .more-link,
	.archive-posts-wrapper .hentry .button,
	.archive-posts-wrapper .hentry button,
	#service-section .more-link,
	#service-section .hentry .button,
	#service-section .hentry button,
	#testimonial-content-section .owl-prev,
	#testimonial-content-section .owl-next {
		color: {$colors['headline_text_color']};
	}

	@media and (min-width: 768px) {
	    .testimonials-content-wrapper.section.testimonial-wrapper .cycle-pager span {
	        color: {$colors['headline_text_color']};
	    }
	}

	/* Link Color */
	a,
	.entry-title a,
	#colophon .widget li,
	.sidebar .widget-wrap p,
	.sidebar .widget-wrap li a,
	.custom-header-content .site-header-text .entry-meta a:hover,
	.custom-header-content .site-header-text .entry-meta a:focus,
	.dropdown-toggle,
	.menu-toggle,
	.menu-label,
	.site-header-menu .menu-inside-wrapper .nav-menu li button,
	.ui-state-active a,
	.ui-state-active a:link,
	.ui-state-active a:visited,
	.social-search-wrapper .menu-social-container li a,
	.menu-social-container a,
	.sidebar nav.social-navigation ul li a:hover,
	.sidebar nav.social-navigation ul li a:focus,
	.screen-reader-text:focus,
	td#today,
	.nav-title,
	.post-title,
	ul.page-numbers li .page-numbers,
	.archive-content-wrap .navigation.pagination .page-numbers,
	.woocommerce.has-header-image .woocommerce-breadcrumb a:hover,
	.woocommerce.has-header-image .woocommerce-breadcrumb a:focus,
	span.breadcrumb a:hover,
	span.breadcrumb a:focus,
	.comments-title,
	.comment-reply-title,
	.widget_recent_entries li a,
	.toggled-on.active:before,
	.comment-respond .comment-form p.is-focused label,
	.contact-section.section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li a,
	.signify-logo-slider-section .section-content-wrapper .entry-title a span,
	.site-header-top-main .contact-details li,
	.filter-button-group .button,
	.filter-button-group .button:hover,
	.filter-button-group .button:focus {
		color: {$colors['link_color']};
	}

	/* Page Post Content Link Color */
	.singular-content-wrap .entry-content a:not(.more-link):not(.button):not(button),
	.singular-content-wrap .entry-summary a:not(.more-link):not(.button):not(button) {
		color: {$colors['page_post_content_link_color']};
	}

	/* Link Hover Color */

	p.stars:hover a:before,
	p.stars:focus a:before,
	.star-rating span:before,
	#menu-toggle:hover,
	#menu-toggle:focus,
	#menu-toggle:hover .menu-label,
	#menu-toggle:focus .menu-label,
	p.stars.selected a.active:before,
	p.stars.selected a:not(.active):before,
	p.stars.selected a.active~a:before,
	p.stars a:hover~a:before,
	p.stars a:focus~a:before,
	.menu-inside-wrapper .main-navigation > .nav-menu >.current_page_item>a,
	.navigation-default .menu-inside-wrapper .main-navigation > .nav-menu .current_page_item > a,
	.menu-inside-wrapper .top-navigation > .nav-menu > .current_page_item>a,
	#reviews .comment-respond .comment-form-rating .stars span a.active:before,
	.page-links .current,
	#site-header-cart-wrapper a.cart-contents .count,
	#reviews .comment-respond .comment-form-rating .stars.selected span a:not(.active):before,
	.contact-details li .fa,
	.section-subtitle,
	.feature-slider-wrapper .entry-container .entry-title span:hover,
	.feature-slider-wrapper .entry-container .entry-title span:focus {
		color: {$colors['link_hover_color']};
	}

	a:hover,
	a:focus,
	.site-title a:hover,
	.site-title a:focus,
	.site-info a:hover,
	.site-info a:focus,
	.post-title:hover,
	.post-title:focus,
	.play-button-text:hover,
	.play-button-text:focus,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-title a:hover,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-title a:focus,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media.navigation-classic .site-header-main .main-navigation > .nav-menu > li > a:hover,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media.navigation-classic .site-header-main .main-navigation > .nav-menu > li > a:focus,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .menu-toggle:hover,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .menu-toggle:focus,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark) .site-header-main .menu-label:hover,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark) .site-header-main .menu-label:focus,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .cart-contents:hover,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .cart-contents:focus,
	.woocommerce .woocommerce-breadcrumb a:hover,
	.woocommerce .woocommerce-breadcrumb a:focus,
    body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-title a:hover,
    body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-title a:focus,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home.navigation-classic .site-header-main .main-navigation > .nav-menu > li > a:hover,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home.navigation-classic .site-header-main .main-navigation > .nav-menu > li > a:focus,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .menu-toggle:hover,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .menu-toggle:focus,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .cart-contents:hover,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .cart-contents:focus,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .menu-label:hover,
	body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .menu-label:focus,
	.has-background-image .woocommerce-loop-product__title:hover,
	.has-background-image .woocommerce-loop-product__title:focus,
	.has-background-image  .entry-container .entry-meta a:hover,
	.has-background-image  .entry-container .entry-meta a:focus,
	.has-background-image  .entry-container .entry-title a:hover,
	.has-background-image  .entry-container .entry-title a:focus,
	.single footer .entry-meta a:hover,
	.single footer .entry-meta a:focus,
	#site-footer-navigation li a:hover,
	#site-footer-navigation li a:focus,
	#social-footer-navigation li a:hover,
	#social-footer-navigation li a:focus,
	.has-background-image .entry-title a:hover,
	.has-background-image .entry-title a:focus,
	.has-background-image .entry-meta a:hover,
	.has-background-image .entry-meta a:focus,
	.wp-playlist-tracks .wp-playlist-caption:hover,
	.wp-playlist-tracks .wp-playlist-caption:focus,
	.signify-mejs-container.mejs-container button:hover,
	.signify-mejs-container.mejs-container button:focus,
	#site-header-cart-wrapper a.cart-contents:hover,
	#site-header-cart-wrapper a.cart-contents:focus,
	.woocommerce-loop-product__title:hover,
	.woocommerce-loop-product__title:focus,
	.events-content-wrapper .entry-meta a:hover,
	.events-content-wrapper .entry-meta a:focus,
	.widget_recent_entries li a:hover,
	.widget_recent_entries li a:focus,
	.menu-inside-wrapper .main-navigation .nav-menu ul > li > a:hover,
	.menu-inside-wrapper .main-navigation .nav-menu ul > li > a:focus,
	.menu-inside-wrapper .top-navigation .nav-menu ul > li > a:hover,
	.menu-inside-wrapper .top-navigation .nav-menu ul > li > a:focus,
	button.dropdown-toggle:hover,
	button.dropdown-toggle:focus,
	.site-header-menu .menu-inside-wrapper .nav-menu li button:hover,
	.site-header-menu .menu-inside-wrapper .nav-menu li button:focus,
	.portfolio-section .entry-title a:hover,
	.portfolio-section .entry-title a:focus,
	.social-search-wrapper .menu-social-container li a:hover,
	.social-search-wrapper .menu-social-container li a:focus,
	button#wp-custom-header-video-button:hover,
	button#wp-custom-header-video-button:focus,
	.widget .ui-state-default a:hover,
	.widget .ui-state-default a:focus,
	.widget .ui-widget-content .ui-state-default a:hover,
	.widget .ui-widget-content .ui-state-default a:focus,
	.widget .ui-widget-header .ui-state-default a:hover,
	.widget .ui-widget-header .ui-state-default a:focus,
	body .site-header .site-header-main .site-header-menu .menu-inside-wrapper .main-navigation .nav-menu ul .current_page_item>a:hover,
	body .site-header .site-header-main .site-header-menu .menu-inside-wrapper .main-navigation .nav-menu ul .current_page_item>a:focus,
	.tag-cloud-link:hover,
	.tag-cloud-link:focus,
	.nav-title:hover,
	.nav-title:focus,
	.menu-social-container a:hover,
	.menu-social-container a:focus,
	.slider-content-wrapper .entry-container .entry-container-wrap .entry-title a:hover,
	.slider-content-wrapper .entry-container .entry-container-wrap .entry-title a:focus,
	.sidebar .widget-wrap .more-link:hover,
	.sidebar .widget-wrap .more-link:focus,
	.featured-content-section .hentry .more-link:hover,
	.featured-content-section .hentry .more-link:focus,
	#portfolio-content-section .more-link:hover,
	#portfolio-content-section .more-link:focus,
	.author a:hover,
	.author a:focus,
	.entry-title a:hover,
	.entry-title a:focus,
	.site-footer td#prev a:hover,
	.site-footer td#prev a:focus,
	.site-footer td#next a:hover,
	.site-footer td#next a:focus,
	.comment-reply-link:hover,
	.comment-reply-link:focus,
	.portfolio-content-wrapper .filter-button-group button:hover,
	.portfolio-content-wrapper .filter-button-group button:focus,
	.author-section-title:hover,
	.author-section-title:focus,
	.comment-permalink:hover,
	.comment-permalink:focus,
	.comment-edit-link:hover,
	.comment-edit-link:focus,
	.portfolio-content-wrapper .filter-button-group button.is-checked:hover,
	.portfolio-content-wrapper .filter-button-group button.is-checked:focus,
	.nav-subtitle:hover,
	.nav-subtitle:focus,
	.entry-meta a:hover,
	.entry-meta a:focus,
	.scroll-down:hover,
	.scroll-down:focus,
	.testimonials-content-wrapper.section.testimonial-wrapper .entry-title a:hover,
	.testimonials-content-wrapper.section.testimonial-wrapper .entry-title a:focus,
	#site-generator .menu-social-container a:hover,
	#site-generator .menu-social-container a:focus,
	.widget-wrap li a:hover,
	.widget-wrap li a:focus,
	.main-navigation ul:not(.sub-menu)>li>a:hover,
	.main-navigation ul:not(.sub-menu)>li>a:focus,
	.top-navigation ul:not(.sub-menu)>li>a:hover,
	.top-navigation ul:not(.sub-menu)>li>a:focus,
	#site-header-cart-wrapper a.cart-contents:hover,
	#site-header-cart-wrapper a.cart-contents:focus,
	#testimonial-content-section .owl-prev:hover,
	#testimonial-content-section .owl-prev:focus,
	#testimonial-content-section .owl-next:hover,
	#testimonial-content-section .owl-next:focus,
	#signify-logo-slider-section .owl-prev:hover,
	#signify-logo-slider-section .owl-prev:focus,
	#signify-logo-slider-section .owl-next:hover,
	#signify-logo-slider-section .owl-next:focus,
	.navigation.pagination a:hover,
	.navigation.pagination a:focus,
	#stats-section.has-background-image .hentry .more-link:hover,
	#stats-section.has-background-image .hentry .more-link:focus,
	.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a:hover,
	.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a:focus,
	.playlist-content-wrapper .signify-mejs-container.mejs-container button:hover,
	.playlist-content-wrapper .signify-mejs-container.mejs-container button:focus,
	button.menu-toggle:hover,
	button.menu-toggle:focus,
	.portfolio-section .entry-meta a:hover,
	.portfolio-section .entry-meta a:focus,
	ul.page-numbers .page-numbers:hover,
	ul.page-numbers .page-numbers:focus,
	.signify-logo-slider-section .section-content-wrapper .entry-title a span:hover,
	.signify-logo-slider-section .section-content-wrapper .entry-title a span:focus,
	#search-top-container .search-submit:hover,
	#search-top-container .search-submit:focus,
	.has-background-image.events-section.style-two .hentry .entry-meta a:hover,
	.has-background-image.events-section.style-two .hentry .entry-meta a:focus,
	#stats-section .entry-title a,
	#featured-content-section .entry-header .entry-meta > span a,
	.product .woocommerce-Price-amount {
		color: {$colors['link_hover_color']};
	}

	#signify-logo-slider-section .owl-dots .owl-dot:hover,
	#signify-logo-slider-section .owl-dots .owl-dot:focus {
		background-color: {$colors['link_hover_color']};
	}

	#signify-logo-slider-section .owl-dots .owl-dot.active,
	#feature-slider-section .owl-dots button.owl-dot.active span,
	.owl-carousel .owl-dots button.owl-dot.active span {
		border-color: {$colors['link_hover_color']};
	}

	@media screen and (min-width: 1200px) {
	    .navigation-classic .menu-inside-wrapper .main-navigation > .nav-menu > .current_page_item > a:before,
	    .navigation-classic .menu-inside-wrapper .top-navigation > .nav-menu > .current_page_item > a:before {
	        border-color: {$colors['link_hover_color']};
	    }
	}

	/* Secondary Link Color */
	ins,
	.entry-breadcrumbs a,
	.woocommerce.woocommerce-active .woocommerce-breadcrumb a,
	p.stars a,
	.single footer .entry-meta a,
	p.stars a:before,
	.entry-meta a,
	.controller:before,
	.tag-cloud-link,
	.select2-results__option,
	body.no-header-media-image .site-header .site-header-main .site-header-menu .menu-inside-wrapper .main-navigation .nav-menu .current_page_item > a,
	#footer-newsletter .wrapper .section-description,
	.widget-wrap span.post-date,
	.contact-section .entry-container a,
	.archive .section-content-wrapper .more-link .readmore,
	.featured-content-section .hentry .more-link,
	.testimonials-content-wrapper.section.testimonial-wrapper .cycle-prev:before,
	.testimonials-content-wrapper.section.testimonial-wrapper .cycle-prev:after,
	.testimonials-content-wrapper.section.testimonial-wrapper .cycle-next:before,
	.clients-content-wrapper .controller .cycle-pager span,
	.testimonials-content-wrapper .cycle-pager:after,
	.slider-content-wrapper .entry-container .entry-container-wrap .entry-summary,
	.portfolio-content-wrapper .filter-button-group button,
	.testimonials-content-wrapper .entry-title a,
	.testimonials-content-wrapper.section.testimonial-wrapper .hentry,
	.scrollup a:hover:before,
	.scrollup a:focus:before,
	.sidebar .widget-wrap .more-link,
	.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:hover,
	.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:focus,
	.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a,
	.author-label,
	.entry-title .sub-title,
	.section-heading-wrapper .entry-title .sub-title,
	.section-heading-wrapper .entry-title span,
	.author-section-title,
	.comment-permalink,
	.comment-edit-link,
	.entry-title span,
	.nav-subtitle,
	.nav-menu .menu-item-has-children>a:before,
	.nav-menu .menu_item_has_children>a:before,
	input,
	select,
	optgroup,
	textarea,
	.playlist-content-wrapper .mejs-time,
	.catch-breadcrumb .entry-breadcrumbs,
	.catch-breadcrumb .woocommerce-breadcrumb {
		color: {$colors['secondary_link_color']};
	}

	/* Button Background Color */

	.more-link,
	.button,
	#feature-slider-section .owl-prev,
	#feature-slider-section .owl-next,
	.section .filter-button-group .button.is-checked:before,
	.pagination .page-numbers.current,
	.entry-content button,
	.entry-summary button,
	button,
	#scrollup,
	.slider-content-wrapper .controllers .cycle-prev,
	.slider-content-wrapper .controllers .cycle-next,
	input[type="submit"],
	button[type="submit"],
	.scrollup a,
	.sticky-post,
	#team-dots li.active:after,
	#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:hover,
	#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:focus,
	.wp-block-button__link,
	#infinite-handle > span > button,
	.menu-inside-wrapper #site-header-cart-wrappe li>a,
	.contact-section .entry-container ul.contact-details li .fa,
	nav.navigation.posts-navigation .nav-links a,
	.page-numbers li .page-numbers.current,
	.archive-content-wrap .pagination .page-numbers.current,
	.cart-collaterals .shop_table.shop_table_responsive .cart-subtotal,
	.catch-instagram-feed-gallery-widget-wrapper .button,
	.sticky-label,
	.wpcf7 input[type=submit]:hover,
	.wpcf7 input[type=submit]:focus,
	.archive-posts-wrapper .more-link:hover,
	.archive-posts-wrapper .more-link:focus,
	.archive-posts-wrapper .button:hover,
	.archive-posts-wrapper .button:focus,
	.archive-posts-wrapper button :hover,
	.archive-posts-wrapper button :focus,
	.comments-area input[type=submit]:hover,
	.comments-area input[type=submit]:focus,
	#service-section .more-link:hover,
	#service-section .hentry .more-link:focus,
	#service-section .hentry .button:hover,
	#service-section .hentry .button:focus,
	#service-section .hentry button:hover,
	#service-section .hentry button:focus,
	#featured-content-section .section-content-wrapper .hentry .more-link:hover,
	#featured-content-section .section-content-wrapper .hentry .more-link:focus,
	#featured-content-section .section-content-wrapper .hentry .button:hover,
	#featured-content-section .section-content-wrapper .hentry .button:focus,
	#featured-content-section .section-content-wrapper .hentry button:hover,
	#featured-content-section .section-content-wrapper .hentry button:focus,
	#stats-section .hentry .more-link:hover,
	#stats-section .hentry .more-link:focus,
	.woocommerce .products .product-container .button:hover,
	.woocommerce .products .product-container .button:focus,
	.woocommerce .products .product-container .added_to_cart:hover,
	.woocommerce .products .product-container .added_to_cart:focus,
	#site-generator #social-footer-navigation a:focus:before,
	#site-generator #social-footer-navigation a:hover:before,
	#feature-slider-section .owl-dots button.owl-dot span,
	#portfolio-content-section .hentry .more-link:hover,
	#portfolio-content-section .hentry .more-link:focus,
	.timeline-section .content-wrapper:before,
	.timeline-section .hentry .hentry-inner:before {
	    background-color: {$colors['button_background_color']};
	}

	.woocommerce .products .product-container .button,
	.woocommerce .products .product-container .added_to_cart,
	.wpcf7 input[type=submit],
	.comments-area input[type=submit],
	.comments-area input[type=submit]:hover,
	.comments-area input[type=submit]:focus,
	#service-section .hentry .more-link,
	#service-section .hentry .button,
	#service-section .hentry button,
	#featured-content-section .section-content-wrapper .hentry .more-link,
	#featured-content-section .section-content-wrapper .hentry .button,
	#featured-content-section .section-content-wrapper .hentry button,
	.archive-posts-wrapper .hentry .more-link,
	.archive-posts-wrapper .hentry .button,
	.archive-posts-wrapper .hentry button {
	    border-color: {$colors['button_background_color']};
	}

	.stats-section .entry-summary .more-link:hover,
	.stats-section .entry-summary .more-link:focus,
	.stats-section .entry-content .more-link:hover,
	.stats-section .entry-content .more-link:focus {
	    color: {$colors['button_background_color']};
	}

	/* Button Text Color */

	.more-link,
	.slider-content-wrapper .controllers .cycle-prev:before,
	.slider-content-wrapper .controllers .cycle-next:before,
	button,
	#scrollup,
	#primary-search-wrapper .search-container button,
	input[type="submit"],
	.button,
	.scroll-down,
	.scrollup a:before,
	.page-numbers.current,
	.page-numbers:hover,
	.page-numbers:focus,
	button[type="submit"],
	.portfolio-section .entry-title a,
	button#wp-custom-header-video-button,
	#infinite-handle > span > button,
	nav.navigation.posts-navigation .nav-links a,
	ul.page-numbers .page-numbers.current,
	#portfolio-content-section .entry-container,
	.slider-content-wrapper #featured-slider-prev:hover:before,
	.slider-content-wrapper #featured-slider-next:hover:before,
	.slider-content-wrapper #featured-slider-prev:focus:before,
	.slider-content-wrapper #featured-slider-next:focus:before,
	.nav-menu .menu-item-has-children>a:hover:before,
	.nav-menu .menu-item-has-children>a:focus:before,
	.nav-menu .menu_item_has_children>a:hover:before,
	.nav-menu .menu_item_has_children>a:focus:before,
	.cart-collaterals .shop_table.shop_table_responsive .cart-subtotal,
	.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:hover a,
	.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:focus a,
	.wpcf7 input[type=submit]:hover,
	.wpcf7 input[type=submit]:focus,
	.comments-area input[type=submit]:hover,
	.comments-area input[type=submit]:focus,
	.archive-posts-wrapper .hentry .more-link:hover,
	.archive-posts-wrapper .hentry .more-link:focus,
	.archive-posts-wrapper .hentry .button:hover,
	.archive-posts-wrapper .hentry .button:focus,
	.archive-posts-wrapper .hentry button:hover,
	.archive-posts-wrapper .hentry button:focus,
	#featured-content-section .section-content-wrapper .hentry .more-link:hover,
	#featured-content-section .section-content-wrapper .hentry .more-link:focus,
	#featured-content-section .section-content-wrapper .hentry .button:hover,
	#featured-content-section .section-content-wrapper .hentry .button:focus,
	#featured-content-section .section-content-wrapper .hentry button:hover,
	#featured-content-section .section-content-wrapper .hentry button:focus,
	.woocommerce .products .product-container .added_to_cart:hover,
	.woocommerce .products .product-container .added_to_cart:focus,
	.product-container a.button:hover,
	.product-container a.button:focus,
	#service-section .hentry .more-link:hover,
	#service-section .hentry .more-link:focus,
	#service-section .hentry .button:hover,
	#service-section .hentry .button:focus,
	#service-section .hentry button:hover,
	#service-section .hentry button:focus,
	.portfolio-section .entry-meta a,
	#portfolio-content-section .hentry .more-link:hover,
	#portfolio-content-section .hentry .more-link:focus {
	    color: {$colors['button_text_color']};
	}

	.owl-carousel .owl-dots button.owl-dot.active span {
	    border-color: {$colors['button_text_color']};
	}

	/* Button Hover Text Color */

	.more-link:hover,
	.more-link:focus,
	button:hover,
	button:focus,
	.button:hover,
	.button:focus,
	.entry-content button:hover,
	.entry-content button:focus,
	.entry-summary button:hover,
	.entry-summary button:focus,
	#social-search-toggle svg:hover,
	#social-search-toggle svg:focus,
	input[type="submit"]:hover,
	input[type="submit"]:focus,
	button[type="submit"]:hover,
	button[type="submit"]:focus,
	#primary-search-wrapper .search-container button:hover,
	#primary-search-wrapper .search-container button:focus,
	#infinite-handle > span > button:hover,
	#infinite-handle > span > button:focus,
	nav.navigation.posts-navigation .nav-links a:hover,
	nav.navigation.posts-navigation .nav-links a:focus,
	ul.page-numbers li:hover,
	ul.page-numbers li:focus,
	.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
	.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
	.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:hover,
	.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:focus,
	.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
	.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
	.has-header-image .custom-header-content .more-link:hover,
	.has-header-image .custom-header-content .more-link:focus,
	#scrollup:hover,
	#scrollup:focus {
	    color: {$colors['button_hover_text_color']};
	}

	#signify-logo-slider-section .owl-dots .owl-dot,
	.owl-carousel .owl-dots button.owl-dot span {
	    background-color: {$colors['button_hover_text_color']};
	}

	.scrollup a:hover:before,
	.scrollup a:focus:before,
	#signify-logo-slider-section .owl-prev,
	#signify-logo-slider-section .owl-next,
	#feature-slider-section .owl-nav button:hover:before,
	#feature-slider-section .owl-nav button:focus:before,
	.owl-carousel .owl-dots button.owl-dot span,
	.comments-area input[type=submit] {
	    color: {$colors['button_hover_text_color']};
	}

	/* Button Hover Background Color */

	.more-link:hover,
	.more-link:focus,
	.button:hover,
	.button:focus,
	#feature-slider-section .owl-dots button.owl-dot span:hover,
	#feature-slider-section .owl-dots button.owl-dot span:focus,
	#contact-section.has-background-image input[type="submit"]:hover,
	#contact-section.has-background-image input[type="submit"]:focus,
	#scrollup:hover,
	#scrollup:focus,
	button:hover,
	button:focus,
	input[type="submit"]:hover,
	input[type="submit"]:focus,
	.scrollup a:hover,
	.scrollup a:focus,
	button[type="submit"]:hover,
	button[type="submit"]:focus,
	.wp-block-button__link:hover,
	.wp-block-button__link:focus,
	#infinite-handle > span > button:hover,
	#infinite-handle > span > button:focus,
	.slider-content-wrapper .cycle-next:hover,
	.slider-content-wrapper .cycle-next:focus,
	.slider-content-wrapper .cycle-prev:hover,
	.slider-content-wrapper .cycle-prev:focus,
	.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:hover,
	.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:focus,
	nav.navigation.posts-navigation .nav-links a:hover,
	nav.navigation.posts-navigation .nav-links a:focus,
	.archive-content-wrap .pagination .page-numbers:hover,
	.archive-content-wrap .pagination .page-numbers:focus,
	.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
	.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
	.has-header-image .custom-header-content .more-link:hover,
	.has-header-image .custom-header-content .more-link:focus,
	#feature-slider-section .more-link:hover,
	#feature-slider-section .more-link:focus {
        background-color: {$colors['button_background_hover_color']};
    }

	/* Border Color */
	.comment-form input,
	#scrollup:hover,
	#scrollup:focus,
	.ewnewsletter .ew-newsletter-wrap #subbutton,
	.woocommerce .single_add_to_cart_button,
	nav.navigation,
	.site-content .archive-posts-wrapper .posts-navigation .nav-links .nav-previous a,
	.woocommerce-tabs .panel,
	.woocommerce-tabs ul.tabs li.active a:after,
	.woocommerce-tabs ul.tabs:after,
	.calendar_wrap tbody tr:first-child,
	.calendar_wrap tbody tr:last-child,
	tfoot,
	tfoot tr td,
	.author-info,
	.wpcf7 div input,
	.wpcf7 div textarea,
	#promotion-section .play-button,
	.woocommerce-shorting-wrapper,
	.woocommerce-tabs ul.tabs.wc-tabs li,
	.menu-wrapper .widget_shopping_cart ul.woocommerce-mini-cart li,
	.entry-summary form.cart,
	.widget_recent_entries li,
	.team-section .team-content-wrapper .hentry .team-social-profile .social-links-menu,
	table,
	caption,
	table th,
	table thead tr,
	table thead th,
	thead th,
	tbody th,
	tbody td,
	tbody tr,
	table.shop_table_responsive tr td,
	table tbody tr,
	table.shop_table_responsive tbody tr:last-child,
	tr:last-child th,
	tr:last-child td,
	.shop_table tfoot tr td,
	.shop_table tfoot tr th,
	table.shop_table.woocommerce-checkout-review-order-table .cart_item td,
	table.shop_table.woocommerce-checkout-review-order-table tr td,
	table.shop_table.woocommerce-checkout-review-order-table tr th,
	.rtl tbody td:last-child,
	.rtl table thead th:last-child,
	.select2-container--default .select2-selection--single,
	table.woocommerce-grouped-product-list.group_table,
	table.woocommerce-grouped-product-list.group_table td,
	table.variations,
	table.variations td,
	.woocommerce-posts-wrapper .summary.entry-summary .woocommerce-product-rating,
	.cart-collaterals .order-total,
	#payment .wc_payment_methods .payment_box,
	.products .product,
	select,
	header .site-header-main,
	abbr,
	acronym,
	.product-quantity input[type="number"],
	.coupon input[type="text"],
	.catch-instagram-feed-gallery-widget-wrapper .button,
	.site-header-cart .widget_shopping_cart,
	.woocommerce-grouped-product-list tr,
	.mobile-social-search,
	.widget .ui-tabs .ui-tabs-panel,
	.site-header-menu .menu-inside-wrapper .nav-menu button:focus,
	header .site-header-menu .menu-inside-wrapper .main-navigation .sub-menu li:last-child,
	header .site-header-menu .menu-inside-wrapper .main-navigation .children li:last-child,
	.comment-body,
	.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link,
	.section:nth-child(2n) + .site-content,
	.archive-content-wrap .section-content-wrapper.layout-one .hentry .hentry-inner .entry-container>.entry-meta,
	.playlist-content-wrapper .wp-playlist .wp-playlist-tracks,
	.content-area .post-navigation .nav-previous,
	.content-area .post-navigation .nav-next,
	.page .site-main .entry-footer .entry-meta > span:not(.edit-link),
	.single .site-main .entry-footer .entry-meta > span:not(.edit-link),
	.events-content-wrapper .hentry,
	.tagcloud a,
	textarea:focus,
	input[type="text"]:focus,
	input[type="email"]:focus,
	input[type="url"]:focus,
	input[type="password"]:focus,
	input[type="search"]:focus,
	input[type="number"]:focus,
	input[type="tel"]:focus,
	input[type="range"]:focus,
	input[type="date"]:focus,
	input[type="month"]:focus,
	input[type="week"]:focus,
	input[type="time"]:focus,
	input[type="datetime"]:focus,
	input[type="datetime-local"]:focus,
	input[type="color"]:focus,
	.wpcf7 div input:focus,
	.wpcf7 div textarea:focus,
	#site-header-menu,
	#content #infinite-handle > span > button:hover,
	#content #infinite-handle > span > button:focus,
	.site-footer-menu .wrapper > #social-footer-navigation,
	.archive-posts-wrapper .layout-one .hentry .hentry-inner,
	.navigation-classic .main-navigation ul ul,
	.top-navigation ul ul,
	#hero-section.section .more-link:hover,
	#hero-section.section .more-link:focus,
	#hero-section.section .button:hover,
	#hero-section.section .button:focus,
	.timeline-section.section .more-link:hover,
	.timeline-section.section .more-link:focus,
	.timeline-section.section .button:hover,
	.timeline-section.section .button:focus,
	#events-section.section .more-link:hover,
	#events-section.section .more-link:focus,
	#events-section.section .button:hover,
	#events-section.section .button:focus,
	.team-section .more-link:hover,
	.team-section .more-link:focus,
	.team-section .button:hover,
	.team-section .button:focus,
	.promotion-section .more-link:hover,
	.promotion-section .more-link:focus,
	.promotion-section .button:hover,
	.promotion-section .button:focus,
	.entry-content .button:hover,
	.entry-summary .button:focus,
	.view-more .button:hover,
	.view-more .button:focus,
	.view-more .more-link:hover,
	.view-more .more-link:focus,
	.entry-content button:hover,
	.entry-summary button:hover,
	#site-header-cart .woocommerce-mini-cart__buttons a:hover,
	#site-header-cart .woocommerce-mini-cart__buttons a:focus,
	.site-content .archive-posts-wrapper .posts-navigation .nav-links > div a:hover,
	.site-content .archive-posts-wrapper .posts-navigation .nav-links > div a:focus,
	tbody tr:last-child th,
	tbody tr:last-child td,
	#site-generator #social-footer-navigation a:before,
	#primary-menu-wrapper #site-header-cart-wrapper,
	.site-header-top-main,
	.site-content + .recent-blog-content-wrapper {
		border-color: {$colors['border_color']};
	}

	/* Text Color With Background color */
	.scroll-down,
	.custom-header .entry-breadcrumbs a,
	.woocommerce .custom-header .woocommerce-breadcrumb a,
	.has-header-image .custom-header .catch-breadcrumb .entry-breadcrumbs,
	.has-header-image .custom-header .catch-breadcrumb .woocommerce-breadcrumb,
	.custom-header-content .entry-title .sub-title,
	.hero-content-wrapper.has-background-image .entry-container,
	.custom-header-content .entry-container,
	.custom-header-content .entry-container .entry-title,
	.ewnewsletter.has-background-image .section-title,
	.testimonials-content-wrapper.section.testimonial-wrapper.has-background-image .hentry,
	.testimonials-content-wrapper.section.testimonial-wrapper.has-background-image .position,
	.slider-content-wrapper.content-frame .entry-container .entry-title a,
	.slider-content-wrapper.content-frame .entry-container .entry-container-wrap .entry-summary,
	.has-background-image .section-title,
	.has-background-image  .entry-container .entry-meta a,
	.has-background-image  .entry-container .entry-title a,
	.has-background-image  .entry-container .entry-title,
	.has-background-image  .entry-container .entry-title span,
	.has-background-image  .entry-container .entry-summary,
	.has-background-image  .entry-container .entry-summary,
	.has-background-image  .entry-container .entry-content,
	.has-background-image  .entry-container .entry-content,
	.has-background-image .woocommerce-loop-product__title,
	.content-color-white .entry-container .entry-title a,
	.content-color-white .entry-container .entry-title,
	.content-color-white .entry-container .entry-content,
	.content-color-white .entry-container .entry-summary,
	.content-color-white .section-description,
	#promotion-section .play-button,
	.has-background-image .products .button,
	.playlist-content-wrapper .wp-playlist-caption,
	#service-section.has-background-image .hentry .more-link,
	#stats-section.has-background-image .hentry .more-link,
	.play-button-text,
	.sticky-post,
	.gallery-caption,
	.has-background-image .event-list-description .entry-summary,
	.has-background-image .event-list-description .entry-content ,
	#contact-section.has-background-image .entry-content,
	#contact-section.has-background-image .entry-summary,
	.playlist-content-wrapper .wp-playlist-tracks,
	#contact-section .entry-container .entry-content .contact-details label,
	#contact-section .entry-container .entry-summary .contact-details label,
	.has-background-image .section-description-wrapper,
	.has-background-image .section-title-wrapper+.section-description,
	.has-background-image .section-title+.section-description,
	.has-background-image .section-title-wrapper+.section-subtitle,
	.has-background-image .section-heading-wrapper>.section-description,
	.has-background-image .section-title+.section-description,
	.has-background-image .section-heading-wrapper>.section-subtitle,
	#playlist-section .signify-mejs-container.mejs-container button {
	    color: {$colors['textcolor_with_background']};
	}
CSS;
}


/**
 * Outputs an Underscore template for generating CSS for the color scheme.
 *
 * The template generates the css dynamically for instant display in the
 * Customizer preview.
 *
 * @since 1.0.0
 */
function signify_color_scheme_css_template() {
	$colors = array(
	'background_color'                                    => '{{ data.background_color }}',
	'header_textcolor'                                    => '{{ data.header_textcolor }}',
	'page_background_color'                               => '{{ data.page_background_color }}',
	'secondary_background_color'                          => '{{ data.secondary_background_color }}',
	'main_text_color'                                     => '{{ data.main_text_color }}',
	'absolute_header_menu_text_color'                     => '{{ data.absolute_header_menu_text_color }}',
	'absolute_header_text_color'                          => '{{ data.absolute_header_text_color }}',
	'custom_header_slider_color'                          => '{{ data.custom_header_slider_color }}',
	'headline_text_color'                                 => '{{ data.headline_text_color }}',
	'link_color'                                          => '{{ data.link_color }}',
	'page_post_content_link_color'                        => '{{ data.page_post_content_link_color }}',
	'link_hover_color'                                    => '{{ data.link_hover_color }}',
	'secondary_link_color'                                => '{{ data.secondary_link_color }}',
	'button_background_color'                             => '{{ data.button_background_color }}',
	'button_text_color'                                   => '{{ data.button_text_color }}',
	'button_hover_text_color'                             => '{{ data.button_hover_text_color }}',
	'button_background_hover_color'                       => '{{ data.button_background_hover_color }}',
	'border_color'                                        => '{{ data.border_color }}',
	'textcolor_with_background'                           => '{{ data.textcolor_with_background }}',
	);
	?>
	<script type="text/html" id="tmpl-signify-color-scheme">
		<?php echo signify_get_color_scheme_css( $colors ); ?>
	</script>
	<?php
}
add_action( 'customize_controls_print_footer_scripts', 'signify_color_scheme_css_template' );

/**
 * Enqueues front-end CSS for the page background color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_page_background_color_css() {
	$color_scheme          = signify_get_color_scheme();
	$default_color         = $color_scheme[2];
	$page_background_color = get_theme_mod( 'page_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $page_background_color === $default_color ) {
		return;
	}

	$css = '
		/* Page Background Color */
		.screen-reader-text:focus,
		.boxed-layout .site,
		.ui-state-active,
		.section:nth-child(odd).hero-section .content-wrapper,
		.section:nth-child(odd) .events-content-wrapper .hentry-inner,
		.ui-widget-content .ui-state-active,
		.ui-widget-header .ui-state-active,
		.onsale,
		#contact-section,
		#contact-section .contact-content-wrapper,
		.comments-area textyarea,
		.comments-area input:not([type="submit"]),
		.comment-form input:not([type="submit"]),
		.comment-form textarea,
		.site-header-menu input[type="search"].search-field,
		.widget input[type="search"].search-field,
		.widget input:not([type="submit"]),
		.widget textarea,
		.section:nth-child(even) + #contact-section .section-content-wrapper input:not([type="submit"]),
		.section:nth-child(even) + #contact-section .section-content-wrapper textarea,
		#search-top-container input[type="search"].search-field,
		.section:nth-child(even).promotion-section.content-frame .entry-container-frame {
			background-color: %1$s;
		}

		.timeline-section .hentry .hentry-inner:before {
		    border-color: %1$s;
		}

		.wp-playlist-light,
		#sticky-playlist-section,
		#sticky-playlist-section .wp-playlist-tracks {
		    background-color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $page_background_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_page_background_color_css', 11 );


/**
 * Enqueues front-end CSS for the secondary background color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_secondary_background_color_css() {
	$color_scheme          			= signify_get_color_scheme();
	$default_color         			= $color_scheme[3];
	$secondary_background_color 	= get_theme_mod( 'secondary_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $secondary_background_color === $default_color ) {
	return;
	}

	$css = '
		/* Secondary Background Color */
		#colophon .widget-area,
		body.boxed-layout,
		.section:nth-child(odd),
		.section:nth-child(even).hero-section .content-wrapper,
		.section:nth-child(even) .events-content-wrapper .hentry-inner,
		.section:nth-child(even) + #contact-section .section-content-wrapper,
		.mejs-controls .mejs-horizontal-volume-slider .mejs-horizontal-volume-total,
		.mejs-controls .mejs-time-rail .mejs-time-total,
		.signify-mejs-container.mejs-container .mejs-controls .mejs-time-rail .mejs-time-loaded,
		.signify-mejs-container.mejs-container .mejs-controls .mejs-time-rail .mejs-time-float,
		ins,
		.sidebar .widget-wrap,
		#primary-search-wrapper .menu-inside-wrapper,
		.menu-inside-wrapper,
		.mobile-social-search,
		#footer-newsletter,
		mark,
		ins,
		.custom-header,
		ul.tabs.wc-tabs li.active a,
		.woocommerce-Tabs-panel,
		.shop_table thead th,
		ul.wc_payment_methods.payment_methods.methods li,
		.comment-respond,
		.widget_shopping_cart,
		pre,
		.widget .ui-tabs .ui-tabs-panel,
		select,
		.select2-container--default .select2-selection--single,
		input[type="text"],
		input[type="email"],
		input[type="url"],
		input[type="password"],
		input[type="search"],
		input[type="number"],
		input[type="tel"],
		input[type="range"],
		input[type="date"],
		input[type="month"],
		input[type="week"],
		input[type="time"],
		input[type="datetime"],
		input[type="datetime-local"],
		input[type="color"],
		textarea,
		.header-top-bar,
		.comment-list .comment .comment-container,
		.promotion-section.content-frame .entry-container-frame:after {
		    background-color: %1$s;
		}

		#sticky-playlist-section,
		.comment-list .comment-author:before {
		    border-color: %1$s;
		}

		@media screen and (min-width: 1024px) {
	    .navigation-classic .site-header .sub-menu,
	    .navigation-classic .site-header .children,
	    .site-header .header-top-bar .sub-menu,
    	.site-header .header-top-bar .children {
	        background-color: %1$s;
	    }
	}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $secondary_background_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_secondary_background_color_css', 11 );

/**
 * Enqueues front-end CSS for the main text color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_main_text_color_css() {
	$color_scheme    = signify_get_color_scheme();
	$default_color   = $color_scheme[4];
	$main_text_color = get_theme_mod( 'main_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $main_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Main Text Color */
		body,
		input,
		select,
		optgroup,
		textarea,
		table a,
		input::placeholder,
		input[type="text"],
		input[type="email"],
		input[type="url"],
		input[type="password"],
		input[type="search"],
		input[type="number"],
		input[type="tel"],
		input[type="range"],
		input[type="date"],
		input[type="month"],
		input[type="week"],
		input[type="time"],
		input[type="datetime"],
		input[type="datetime-local"],
		input[type="color"],
		.singular-content-wrap .entry-content a:not(.more-link):not(.button):not(button):hover,
		.singular-content-wrap .entry-content a:not(.more-link):not(.button):not(button):focus,
		.singular-content-wrap .entry-summary a:not(.more-link):not(.button):not(button):hover,
		.singular-content-wrap .entry-summary a:not(.more-link):not(.button):not(button):focus,
		.has-background-image.events-section .hentry .event-list-description .entry-summary,
		.has-background-image.events-section .hentry .event-list-description .entry-content,
		#search-top-container .search-submit {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $main_text_color) );
}
add_action( 'wp_enqueue_scripts', 'signify_main_text_color_css', 11 );


/**
 * Enqueues front-end CSS for the Absolute Header Menu Text Color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_absolute_header_menu_text_color_css() {
	$color_scheme    = signify_get_color_scheme();
	$default_color   = $color_scheme[5];
	$absolute_header_menu_text_color = get_theme_mod( 'absolute_header_menu_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $absolute_header_menu_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Aboslute Header Menu Text Color */
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .menu-toggle,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .menu-label,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .menu-toggle,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .menu-label {
		    color: %1$s;
		}

		@media screen and (min-width: 1200px) {
		    body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media.navigation-classic .site-header-main .main-navigation > .nav-menu > li > a,
		    body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home.navigation-classic .site-header-main .main-navigation > .nav-menu > li > a {
		        color: %1$s;
		    }
		}

		@media screen and (min-width: 767px) {
		   body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .cart-contents,
		   body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .cart-contents {
		        color: %1$s;
		    }
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $absolute_header_menu_text_color) );
}
add_action( 'wp_enqueue_scripts', 'signify_absolute_header_menu_text_color_css', 11 );

/**
 * Enqueues front-end CSS for the Absolute Header Text Color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_absolute_header_text_color_css() {
	$color_scheme    = signify_get_color_scheme();
	$default_color   = $color_scheme[6];
	$absolute_header_text_color = get_theme_mod( 'absolute_header_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $absolute_header_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Aboslute Header Text Color */
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-title a,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-description,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-title a,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-description {
		    color: %1$s;
		}

	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $absolute_header_text_color) );
}
add_action( 'wp_enqueue_scripts', 'signify_absolute_header_text_color_css', 11 );

/**
 * Enqueues front-end CSS for the Custom Header and Slider Color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_custom_header_slider_color_css() {
	$color_scheme    = signify_get_color_scheme();
	$default_color   = $color_scheme[7];
	$custom_header_slider_color = get_theme_mod( 'custom_header_slider_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $custom_header_slider_color === $default_color ) {
		return;
	}

	$css = '
		/* Custom Header and Slider Color */
		.header-media-tagline,
		.custom-header .section-title,
		.custom-header .site-header-text,
		.feature-slider-wrapper .entry-container .entry-title,
		.feature-slider-wrapper .entry-container .entry-title span,
		.feature-slider-wrapper .entry-container .entry-summary,
		.feature-slider-wrapper .entry-container .entry-content {
		    color: %1$s;
		}
	}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $custom_header_slider_color) );
}
add_action( 'wp_enqueue_scripts', 'signify_custom_header_slider_color_css', 11 );


/**
 * Enqueues front-end CSS for the headline text color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_headline_text_color_css() {
	$color_scheme        = signify_get_color_scheme();
	$default_color       = $color_scheme[8];
	$headline_text_color = get_theme_mod( 'headline_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $headline_text_color === $default_color ) {
	return;
	}

	$css = '
		/* Headline Text Color */
		h1,
		h2,
		h3,
		h4,
		h5,
		h6,
		.section-title,
		.vcard,
		.has-background-image.events-section .hentry .entry-title a,
		.has-background-image.events-section .hentry .entry-title,
		.has-background-image.events-section.style-two .hentry .entry-meta a,
		#featured-content-section .section-content-wrapper .hentry .more-link,
		#featured-content-section .section-content-wrapper .hentry .button,
		#featured-content-section .section-content-wrapper .hentry button,
		.wpcf7 input[type=submit],
		.position,
		.section-description-wrapper,
		.section-title-wrapper+.section-description,
		.section-title+.section-description,
		.section-title-wrapper+.section-subtitle,
		.section-heading-wrapper>.section-description,
		.section-title+.section-description,
		.drop-cap:first-letter,
		#featured-content-section .entry-header .entry-meta > span a:hover,
		#featured-content-section .entry-header .entry-meta > span a:focus,
		.product .woocommerce-Price-amount:hover,
		.product .woocommerce-Price-amount:focus,
		#stats-section .entry-title a:hover,
		#stats-section .entry-title a:focus,
		.product-container a.button,
		.author-name,
		.comment-reply-link,
		.author-title,
		.stats-section .entry-summary .more-link,
		.stats-section .entry-content .more-link,
		.comment-respond .comment-form p label,
		blockquote,
		.woocommerce .products .product-container .added_to_cart,
		.signify-mejs-container.mejs-container button,
		.archive-posts-wrapper .hentry .more-link,
		.archive-posts-wrapper .hentry .button,
		.archive-posts-wrapper .hentry button,
		#service-section .more-link,
		#service-section .hentry .button,
		#service-section .hentry button,
		#testimonial-content-section .owl-prev,
		#testimonial-content-section .owl-next {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $headline_text_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_headline_text_color_css', 11 );

/**
 * Enqueues front-end CSS for the link color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_link_color_css() {
	$color_scheme    = signify_get_color_scheme();
	$default_color   = $color_scheme[9];
	$link_color = get_theme_mod( 'link_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $link_color === $default_color ) {
		return;
	}

	$css = '
		/* Link Color */
		a,
		.entry-title a,
		#colophon .widget li,
		.sidebar .widget-wrap p,
		.sidebar .widget-wrap li a,
		.custom-header-content .site-header-text .entry-meta a:hover,
		.custom-header-content .site-header-text .entry-meta a:focus,
		.dropdown-toggle,
		.menu-toggle,
		.menu-label,
		.site-header-menu .menu-inside-wrapper .nav-menu li button,
		.ui-state-active a,
		.ui-state-active a:link,
		.ui-state-active a:visited,
		.social-search-wrapper .menu-social-container li a,
		.menu-social-container a,
		.sidebar nav.social-navigation ul li a:hover,
		.sidebar nav.social-navigation ul li a:focus,
		.screen-reader-text:focus,
		td#today,
		.nav-title,
		.post-title,
		ul.page-numbers li .page-numbers,
		.archive-content-wrap .navigation.pagination .page-numbers,
		.woocommerce.has-header-image .woocommerce-breadcrumb a:hover,
		.woocommerce.has-header-image .woocommerce-breadcrumb a:focus,
		span.breadcrumb a:hover,
		span.breadcrumb a:focus,
		.comments-title,
		.comment-reply-title,
		.widget_recent_entries li a,
		.toggled-on.active:before,
		.comment-respond .comment-form p.is-focused label,
		.contact-section.section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li a,
		.signify-logo-slider-section .section-content-wrapper .entry-title a span,
		.site-header-top-main .contact-details li,
		.filter-button-group .button, {
		.filter-button-group .button:hover,
		.filter-button-group .button:focus
			color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $link_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_link_color_css', 11 );

/**
 * Enqueues front-end CSS for the page post content link color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_page_post_content_link_color_css() {
	$color_scheme    = signify_get_color_scheme();
	$default_color   = $color_scheme[10];
	$page_post_content_link_color = get_theme_mod( 'page_post_content_link_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $page_post_content_link_color === $default_color ) {
		return;
	}

	$css = '
		/* Page Post Content Link Color */
		.singular-content-wrap .entry-content a:not(.more-link):not(.button):not(button),
		.singular-content-wrap .entry-summary a:not(.more-link):not(.button):not(button) {
		    color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $page_post_content_link_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_page_post_content_link_color_css', 11 );


/**
 * Enqueues front-end CSS for the link hover color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_link_hover_color_css() {
	$color_scheme     = signify_get_color_scheme();
	$default_color    = $color_scheme[11];
	$link_hover_color = get_theme_mod( 'link_hover_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $link_hover_color === $default_color ) {
		return;
	}

	$css = '
		/* Link Hover Color */
		p.stars:hover a:before,
		p.stars:focus a:before,
		.star-rating span:before,
		#menu-toggle:hover,
		#menu-toggle:focus,
		#menu-toggle:hover .menu-label,
		#menu-toggle:focus .menu-label,
		p.stars.selected a.active:before,
		p.stars.selected a:not(.active):before,
		p.stars.selected a.active~a:before,
		p.stars a:hover~a:before,
		p.stars a:focus~a:before,
		.menu-inside-wrapper .main-navigation > .nav-menu >.current_page_item>a,
		.navigation-default .menu-inside-wrapper .main-navigation > .nav-menu .current_page_item > a,
		.menu-inside-wrapper .top-navigation > .nav-menu > .current_page_item>a,
		#reviews .comment-respond .comment-form-rating .stars span a.active:before,
		.page-links .current,
		#site-header-cart-wrapper a.cart-contents .count,
		#reviews .comment-respond .comment-form-rating .stars.selected span a:not(.active):before,
		.contact-details li .fa,
		.section-subtitle,
		.feature-slider-wrapper .entry-container .entry-title span:hover,
		.feature-slider-wrapper .entry-container .entry-title span:focus {
			color: %1$s;
		}

		a:hover,
		a:focus,
		.site-title a:hover,
		.site-title a:focus,
		.site-info a:hover,
		.site-info a:focus,
		.post-title:hover,
		.post-title:focus,
		.play-button-text:hover,
		.play-button-text:focus,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-title a:hover,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-title a:focus,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .main-navigation .nav-menu > li > a:hover,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .main-navigation .nav-menu > li > a:focus,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .menu-toggle:hover,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .menu-toggle:focus,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark) .site-header-main .menu-label:hover,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark) .site-header-main .menu-label:focus,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .cart-contents:hover,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).has-header-media .site-header-main .cart-contents:focus,
		.woocommerce .woocommerce-breadcrumb a:hover,
		.woocommerce .woocommerce-breadcrumb a:focus,
	    body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-title a:hover,
	    body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-title a:focus,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .main-navigation .nav-menu > li > a:hover,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .main-navigation .nav-menu > li > a:focus,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .menu-toggle:hover,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .menu-toggle:focus,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .cart-contents:hover,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .cart-contents:focus,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .menu-label:hover,
		body[class*="color-scheme-"]:not(.color-scheme-ecommerce):not(.color-scheme-education):not(.color-scheme-default):not(.color-scheme-dark).home .site-header-main .menu-label:focus,
		.has-background-image .woocommerce-loop-product__title:hover,
		.has-background-image .woocommerce-loop-product__title:focus,
		.has-background-image  .entry-container .entry-meta a:hover,
		.has-background-image  .entry-container .entry-meta a:focus,
		.has-background-image  .entry-container .entry-title a:hover,
		.has-background-image  .entry-container .entry-title a:focus,
		.single footer .entry-meta a:hover,
		.single footer .entry-meta a:focus,
		#site-footer-navigation li a:hover,
		#site-footer-navigation li a:focus,
		#social-footer-navigation li a:hover,
		#social-footer-navigation li a:focus,
		.has-background-image .entry-title a:hover,
		.has-background-image .entry-title a:focus,
		.has-background-image .entry-meta a:hover,
		.has-background-image .entry-meta a:focus,
		.wp-playlist-tracks .wp-playlist-caption:hover,
		.wp-playlist-tracks .wp-playlist-caption:focus,
		.signify-mejs-container.mejs-container button:hover,
		.signify-mejs-container.mejs-container button:focus,
		#site-header-cart-wrapper a.cart-contents:hover,
		#site-header-cart-wrapper a.cart-contents:focus,
		.woocommerce-loop-product__title:hover,
		.woocommerce-loop-product__title:focus,
		.events-content-wrapper .entry-meta a:hover,
		.events-content-wrapper .entry-meta a:focus,
		.widget_recent_entries li a:hover,
		.widget_recent_entries li a:focus,
		.menu-inside-wrapper .main-navigation .nav-menu ul > li > a:hover,
		.menu-inside-wrapper .main-navigation .nav-menu ul > li > a:focus,
		.menu-inside-wrapper .top-navigation .nav-menu ul > li > a:hover,
		.menu-inside-wrapper .top-navigation .nav-menu ul > li > a:focus,
		button.dropdown-toggle:hover,
		button.dropdown-toggle:focus,
		.site-header-menu .menu-inside-wrapper .nav-menu li button:hover,
		.site-header-menu .menu-inside-wrapper .nav-menu li button:focus,
		.portfolio-section .entry-title a:hover,
		.portfolio-section .entry-title a:focus,
		.social-search-wrapper .menu-social-container li a:hover,
		.social-search-wrapper .menu-social-container li a:focus,
		button#wp-custom-header-video-button:hover,
		button#wp-custom-header-video-button:focus,
		.widget .ui-state-default a:hover,
		.widget .ui-state-default a:focus,
		.widget .ui-widget-content .ui-state-default a:hover,
		.widget .ui-widget-content .ui-state-default a:focus,
		.widget .ui-widget-header .ui-state-default a:hover,
		.widget .ui-widget-header .ui-state-default a:focus,
		body .site-header .site-header-main .site-header-menu .menu-inside-wrapper .main-navigation .nav-menu ul .current_page_item>a:hover,
		body .site-header .site-header-main .site-header-menu .menu-inside-wrapper .main-navigation .nav-menu ul .current_page_item>a:focus,
		.tag-cloud-link:hover,
		.tag-cloud-link:focus,
		.nav-title:hover,
		.nav-title:focus,
		.menu-social-container a:hover,
		.menu-social-container a:focus,
		.slider-content-wrapper .entry-container .entry-container-wrap .entry-title a:hover,
		.slider-content-wrapper .entry-container .entry-container-wrap .entry-title a:focus,
		.sidebar .widget-wrap .more-link:hover,
		.sidebar .widget-wrap .more-link:focus,
		.featured-content-section .hentry .more-link:hover,
		.featured-content-section .hentry .more-link:focus,
		#portfolio-content-section .more-link:hover,
		#portfolio-content-section .more-link:focus,
		.author a:hover,
		.author a:focus,
		.entry-title a:hover,
		.entry-title a:focus,
		.site-footer td#prev a:hover,
		.site-footer td#prev a:focus,
		.site-footer td#next a:hover,
		.site-footer td#next a:focus,
		.comment-reply-link:hover,
		.comment-reply-link:focus,
		.portfolio-content-wrapper .filter-button-group button:hover,
		.portfolio-content-wrapper .filter-button-group button:focus,
		.author-section-title:hover,
		.author-section-title:focus,
		.comment-permalink:hover,
		.comment-permalink:focus,
		.comment-edit-link:hover,
		.comment-edit-link:focus,
		.portfolio-content-wrapper .filter-button-group button.is-checked:hover,
		.portfolio-content-wrapper .filter-button-group button.is-checked:focus,
		.nav-subtitle:hover,
		.nav-subtitle:focus,
		.entry-meta a:hover,
		.entry-meta a:focus,
		.scroll-down:hover,
		.scroll-down:focus,
		.testimonials-content-wrapper.section.testimonial-wrapper .entry-title a:hover,
		.testimonials-content-wrapper.section.testimonial-wrapper .entry-title a:focus,
		#site-generator .menu-social-container a:hover,
		#site-generator .menu-social-container a:focus,
		.widget-wrap li a:hover,
		.widget-wrap li a:focus,
		.main-navigation ul:not(.sub-menu)>li>a:hover,
		.main-navigation ul:not(.sub-menu)>li>a:focus,
		.top-navigation ul:not(.sub-menu)>li>a:hover,
		.top-navigation ul:not(.sub-menu)>li>a:focus,
		#site-header-cart-wrapper a.cart-contents:hover,
		#site-header-cart-wrapper a.cart-contents:focus,
		#testimonial-content-section .owl-prev:hover,
		#testimonial-content-section .owl-prev:focus,
		#testimonial-content-section .owl-next:hover,
		#testimonial-content-section .owl-next:focus,
		#signify-logo-slider-section .owl-prev:hover,
		#signify-logo-slider-section .owl-prev:focus,
		#signify-logo-slider-section .owl-next:hover,
		#signify-logo-slider-section .owl-next:focus,
		.navigation.pagination a:hover,
		.navigation.pagination a:focus,
		#stats-section.has-background-image .hentry .more-link:hover,
		#stats-section.has-background-image .hentry .more-link:focus,
		.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a:hover,
		.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a:focus,
		.playlist-content-wrapper .signify-mejs-container.mejs-container button:hover,
		.playlist-content-wrapper .signify-mejs-container.mejs-container button:focus,
		button.menu-toggle:hover,
		button.menu-toggle:focus,
		.portfolio-section .entry-meta a:hover,
		.portfolio-section .entry-meta a:focus,
		ul.page-numbers .page-numbers:hover,
		ul.page-numbers .page-numbers:focus,
		.signify-logo-slider-section .section-content-wrapper .entry-title a span:hover,
		.signify-logo-slider-section .section-content-wrapper .entry-title a span:focus,
		#search-top-container .search-submit:hover,
		#search-top-container .search-submit:focus,
		.has-background-image.events-section.style-two .hentry .entry-meta a:hover,
		.has-background-image.events-section.style-two .hentry .entry-meta a:focus,
		#stats-section .entry-title a,
		#featured-content-section .entry-header .entry-meta > span a,
		.product .woocommerce-Price-amount {
			color: %1$s;
		}

		#signify-logo-slider-section .owl-dots .owl-dot:hover,
		#signify-logo-slider-section .owl-dots .owl-dot:focus {
			background-color: %1$s;
		}

		#signify-logo-slider-section .owl-dots .owl-dot.active,
		#feature-slider-section .owl-dots button.owl-dot.active span,
		.owl-carousel .owl-dots button.owl-dot.active span {
			border-color: %1$s;
		}

		@media screen and (min-width: 1200px) {
		    .navigation-classic .menu-inside-wrapper .main-navigation > .nav-menu > .current_page_item > a:before,
		    .navigation-classic .menu-inside-wrapper .top-navigation > .nav-menu > .current_page_item > a:before {
		        border-color: %1$s;
		    }
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $link_hover_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_link_hover_color_css', 11 );


/**
 * Enqueues front-end CSS for the secondary link color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_secondary_link_color_css() {
	$color_scheme         = signify_get_color_scheme();
	$default_color        = $color_scheme[12];
	$secondary_link_color = get_theme_mod( 'secondary_link_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $secondary_link_color === $default_color ) {
		return;
	}

	$css = '
		/* Secondary Link Color */
		ins,
		.entry-breadcrumbs a,
		.woocommerce.woocommerce-active .woocommerce-breadcrumb a,
		p.stars a,
		.single footer .entry-meta a,
		p.stars a:before,
		.entry-meta a,
		.controller:before,
		.tag-cloud-link,
		.select2-results__option,
		body.no-header-media-image .site-header .site-header-main .site-header-menu .menu-inside-wrapper .main-navigation .nav-menu .current_page_item > a,
		#footer-newsletter .wrapper .section-description,
		.widget-wrap span.post-date,
		.contact-section .entry-container a,
		.archive .section-content-wrapper .more-link .readmore,
		.featured-content-section .hentry .more-link,
		.testimonials-content-wrapper.section.testimonial-wrapper .cycle-prev:before,
		.testimonials-content-wrapper.section.testimonial-wrapper .cycle-prev:after,
		.testimonials-content-wrapper.section.testimonial-wrapper .cycle-next:before,
		.clients-content-wrapper .controller .cycle-pager span,
		.testimonials-content-wrapper .cycle-pager:after,
		.slider-content-wrapper .entry-container .entry-container-wrap .entry-summary,
		.portfolio-content-wrapper .filter-button-group button,
		.testimonials-content-wrapper .entry-title a,
		.testimonials-content-wrapper.section.testimonial-wrapper .hentry,
		.scrollup a:hover:before,
		.scrollup a:focus:before,
		.sidebar .widget-wrap .more-link,
		.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:hover,
		.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:focus,
		.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a,
		.author-label,
		.entry-title .sub-title,
		.section-heading-wrapper .entry-title .sub-title,
		.section-heading-wrapper .entry-title span,
		.author-section-title,
		.comment-permalink,
		.comment-edit-link,
		.entry-title span,
		.nav-subtitle,
		.nav-menu .menu-item-has-children>a:before,
		.nav-menu .menu_item_has_children>a:before,
		input,
		select,
		optgroup,
		textarea,
		.playlist-content-wrapper .mejs-time,
		.catch-breadcrumb .entry-breadcrumbs,
		.catch-breadcrumb .woocommerce-breadcrumb {
			color: %1$s;
		}
	';
	wp_add_inline_style( 'signify-block-style', sprintf( $css, $secondary_link_color) );
}
add_action( 'wp_enqueue_scripts', 'signify_secondary_link_color_css', 11 );

/**
 * Enqueues front-end CSS for the Button background color
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_button_background_color_css() {
	$color_scheme   = signify_get_color_scheme();
	$default_color  = $color_scheme[13];
	$button_background_color 	= get_theme_mod( 'button_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $button_background_color === $default_color ) {
		return;
	}

	$css = '
		/* Button Background Color */
		.more-link,
		.button,
		#feature-slider-section .owl-prev,
		#feature-slider-section .owl-next,
		.section .filter-button-group .button.is-checked:before,
		.pagination .page-numbers.current,
		.entry-content button,
		.entry-summary button,
		button,
		#scrollup,
		.slider-content-wrapper .controllers .cycle-prev,
		.slider-content-wrapper .controllers .cycle-next,
		input[type="submit"],
		button[type="submit"],
		.scrollup a,
		.sticky-post,
		#team-dots li.active:after,
		#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:hover,
		#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:focus,
		.wp-block-button__link,
		#infinite-handle > span > button,
		.menu-inside-wrapper #site-header-cart-wrappe li>a,
		.contact-section .entry-container ul.contact-details li .fa,
		nav.navigation.posts-navigation .nav-links a,
		.page-numbers li .page-numbers.current,
		.archive-content-wrap .pagination .page-numbers.current,
		.cart-collaterals .shop_table.shop_table_responsive .cart-subtotal,
		.catch-instagram-feed-gallery-widget-wrapper .button,
		.sticky-label,
		.wpcf7 input[type=submit]:hover,
		.wpcf7 input[type=submit]:focus,
		.archive-posts-wrapper .more-link:hover,
		.archive-posts-wrapper .more-link:focus,
		.archive-posts-wrapper .button:hover,
		.archive-posts-wrapper .button:focus,
		.archive-posts-wrapper button :hover,
		.archive-posts-wrapper button :focus,
		.comments-area input[type=submit]:hover,
		.comments-area input[type=submit]:focus,
		#service-section .more-link:hover,
		#service-section .hentry .more-link:focus,
		#service-section .hentry .button:hover,
		#service-section .hentry .button:focus,
		#service-section .hentry button:hover,
		#service-section .hentry button:focus,
		#featured-content-section .section-content-wrapper .hentry .more-link:hover,
		#featured-content-section .section-content-wrapper .hentry .more-link:focus,
		#featured-content-section .section-content-wrapper .hentry .button:hover,
		#featured-content-section .section-content-wrapper .hentry .button:focus,
		#featured-content-section .section-content-wrapper .hentry button:hover,
		#featured-content-section .section-content-wrapper .hentry button:focus,
		#stats-section .hentry .more-link:hover,
		#stats-section .hentry .more-link:focus,
		.woocommerce .products .product-container .button:hover,
		.woocommerce .products .product-container .button:focus,
		.woocommerce .products .product-container .added_to_cart:hover,
		.woocommerce .products .product-container .added_to_cart:focus,
		#site-generator #social-footer-navigation a:focus:before,
		#site-generator #social-footer-navigation a:hover:before,
		#feature-slider-section .owl-dots button.owl-dot span,
		#portfolio-content-section .hentry .more-link:hover,
		#portfolio-content-section .hentry .more-link:focus,
		.timeline-section .content-wrapper:before,
		.timeline-section .hentry .hentry-inner:before {
			background-color: %1$s;
		}

		.stats-section .entry-summary .more-link:hover,
		.stats-section .entry-summary .more-link:focus,
		.stats-section .entry-content .more-link:hover,
		.stats-section .entry-content .more-link:focus {
		    color: %1$s;
		}


		.woocommerce .products .product-container .button,
		.woocommerce .products .product-container .added_to_cart,
		.wpcf7 input[type=submit],
		.comments-area input[type=submit],
		.comments-area input[type=submit]:hover,
		.comments-area input[type=submit]:focus,
		#service-section .hentry .more-link,
		#service-section .hentry .button,
		#service-section .hentry button,
		#featured-content-section .section-content-wrapper .hentry .more-link,
		#featured-content-section .section-content-wrapper .hentry .button,
		#featured-content-section .section-content-wrapper .hentry button,
		.archive-posts-wrapper .hentry .more-link,
		.archive-posts-wrapper .hentry .button,
		.archive-posts-wrapper .hentry button {
		    border-color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $button_background_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_button_background_color_css', 11 );


/**
 * Enqueues front-end CSS for the button text color
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_button_text_color_css() {
	$color_scheme      = signify_get_color_scheme();
	$default_color     = $color_scheme[14];
	$button_text_color = get_theme_mod( 'button_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $button_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Button Text Color */
		.more-link,
		#feature-slider-section .owl-prev:before,
		#feature-slider-section .owl-next:before,
		.slider-content-wrapper .controllers .cycle-prev,
		.slider-content-wrapper .controllers .cycle-next,
		button,
		#scrollup,
		#primary-search-wrapper .search-container button,
		input[type="submit"],
		.button,
		.scroll-down,
		.scrollup a:before,
		.page-numbers.current,
		.page-numbers:hover,
		.page-numbers:focus,
		button[type="submit"],
		.portfolio-section .entry-title a,
		button#wp-custom-header-video-button,
		#infinite-handle > span > button,
		nav.navigation.posts-navigation .nav-links a,
		ul.page-numbers .page-numbers.current,
		#portfolio-content-section .entry-container,
		.slider-content-wrapper #featured-slider-prev:hover:before,
		.slider-content-wrapper #featured-slider-next:hover:before,
		.slider-content-wrapper #featured-slider-prev:focus:before,
		.slider-content-wrapper #featured-slider-next:focus:before,
		.nav-menu .menu-item-has-children>a:hover:before,
		.nav-menu .menu-item-has-children>a:focus:before,
		.nav-menu .menu_item_has_children>a:hover:before,
		.nav-menu .menu_item_has_children>a:focus:before,
		.cart-collaterals .shop_table.shop_table_responsive .cart-subtotal,
		.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:hover a,
		.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:focus a,
		.wpcf7 input[type=submit]:hover,
		.wpcf7 input[type=submit]:focus,
		.comments-area input[type=submit]:hover,
		.comments-area input[type=submit]:focus,
		.archive-posts-wrapper .hentry .more-link:hover,
		.archive-posts-wrapper .hentry .more-link:focus,
		.archive-posts-wrapper .hentry .button:hover,
		.archive-posts-wrapper .hentry .button:focus,
		.archive-posts-wrapper .hentry button:hover,
		.archive-posts-wrapper .hentry button:focus,
		#featured-content-section .section-content-wrapper .hentry .more-link:hover,
		#featured-content-section .section-content-wrapper .hentry .more-link:focus,
		#featured-content-section .section-content-wrapper .hentry .button:hover,
		#featured-content-section .section-content-wrapper .hentry .button:focus,
		#featured-content-section .section-content-wrapper .hentry button:hover,
		#featured-content-section .section-content-wrapper .hentry button:focus,
		.woocommerce .products .product-container .added_to_cart:hover,
		.woocommerce .products .product-container .added_to_cart:focus,
		.product-container a.button:hover,
		.product-container a.button:focus,
		#service-section .hentry .more-link:hover,
		#service-section .hentry .more-link:focus,
		#service-section .hentry .button:hover,
		#service-section .hentry .button:focus,
		#service-section .hentry button:hover,
		#service-section .hentry button:focus,
		.portfolio-section .entry-meta a,
		#portfolio-content-section .hentry .more-link:hover,
		#portfolio-content-section .hentry .more-link:focus {
			color: %1$s;
		}

		.owl-carousel .owl-dots button.owl-dot.active span {
		    border-color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $button_text_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_button_text_color_css', 11 );


/**
 * Enqueues front-end CSS for the button hover text color
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_button_hover_text_color_css() {
	$color_scheme            = signify_get_color_scheme();
	$default_color           = $color_scheme[15];
	$button_hover_text_color = get_theme_mod( 'button_hover_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $button_hover_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Button Hover Text Color */
		.more-link:hover,
		.more-link:focus,
		button:hover,
		button:focus,
		.button:hover,
		.button:focus,
		.entry-content button:hover,
		.entry-content button:focus,
		.entry-summary button:hover,
		.entry-summary button:focus,
		#social-search-toggle svg:hover,
		#social-search-toggle svg:focus,
		input[type="submit"]:hover,
		input[type="submit"]:focus,
		button[type="submit"]:hover,
		button[type="submit"]:focus,
		#primary-search-wrapper .search-container button:hover,
		#primary-search-wrapper .search-container button:focus,
		#infinite-handle > span > button:hover,
		#infinite-handle > span > button:focus,
		nav.navigation.posts-navigation .nav-links a:hover,
		nav.navigation.posts-navigation .nav-links a:focus,
		ul.page-numbers li:hover,
		ul.page-numbers li:focus,
		.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
		.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
		.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:hover,
		.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:focus,
		.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
		.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
		.has-header-image .custom-header-content .more-link:hover,
		.has-header-image .custom-header-content .more-link:focus,
		#scrollup:hover,
		#scrollup:focus {
		    color: %1$s;
		}

		#signify-logo-slider-section .owl-dots .owl-dot,
		.owl-carousel .owl-dots button.owl-dot span {
		    background-color: %1$s;
		}

		.scrollup a:hover:before,
		.scrollup a:focus:before,
		#feature-slider-section .owl-nav button:hover:before,
		#feature-slider-section .owl-nav button:focus:before,
		#signify-logo-slider-section .owl-prev,
		#signify-logo-slider-section .owl-next,
		.owl-carousel .owl-dots button.owl-dot span,
		.comments-area input[type=submit] {
		    color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $button_hover_text_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_button_hover_text_color_css', 11 );

/**
 * Enqueues front-end CSS for the Button Hover Background Color
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_button_background_hover_color_css() {
	$color_scheme   = signify_get_color_scheme();
	$default_color  = $color_scheme[16];
	$button_background_hover_color 	= get_theme_mod( 'button_background_hover_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $button_background_hover_color === $default_color ) {
		return;
	}

	$css = '
		/* Button Hover Background Color */
		.more-link:hover,
		.more-link:focus,
		.button:hover,
		.button:focus,
		#feature-slider-section .owl-dots button.owl-dot span:hover,
		#feature-slider-section .owl-dots button.owl-dot span:focus,
		#contact-section.has-background-image input[type="submit"]:hover,
		#contact-section.has-background-image input[type="submit"]:focus,
		#scrollup:hover,
		#scrollup:focus,
		button:hover,
		button:focus,
		input[type="submit"]:hover,
		input[type="submit"]:focus,
		.scrollup a:hover,
		.scrollup a:focus,
		button[type="submit"]:hover,
		button[type="submit"]:focus,
		.wp-block-button__link:hover,
		.wp-block-button__link:focus,
		#infinite-handle > span > button:hover,
		#infinite-handle > span > button:focus,
		.slider-content-wrapper .cycle-next:hover,
		.slider-content-wrapper .cycle-next:focus,
		.slider-content-wrapper .cycle-prev:hover,
		.slider-content-wrapper .cycle-prev:focus,
		.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:hover,
		.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:focus,
		nav.navigation.posts-navigation .nav-links a:hover,
		nav.navigation.posts-navigation .nav-links a:focus,
		.archive-content-wrap .pagination .page-numbers:hover,
		.archive-content-wrap .pagination .page-numbers:focus,
		.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
		.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
		.has-header-image .custom-header-content .more-link:hover,
		.has-header-image .custom-header-content .more-link:focus,
		#feature-slider-section .more-link:hover,
		#feature-slider-section .more-link:focus {
			border-color: %1$s;
		}

		#signify-logo-slider-section {
		    background-color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $button_background_hover_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_button_background_hover_color_css', 11 );

/**
 * Enqueues front-end CSS for the border color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_border_color_css() {
	$color_scheme   = signify_get_color_scheme();
	$default_color  = $color_scheme[17];
	$border_color 	= get_theme_mod( 'border_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $border_color === $default_color ) {
		return;
	}

	$css = '
		/* Border Color */
		.comment-form input,
		#scrollup:hover,
		#scrollup:focus,
		.ewnewsletter .ew-newsletter-wrap #subbutton,
		.woocommerce .single_add_to_cart_button,
		nav.navigation,
		.site-content .archive-posts-wrapper .posts-navigation .nav-links .nav-previous a,
		.woocommerce-tabs .panel,
		.woocommerce-tabs ul.tabs li.active a:after,
		.woocommerce-tabs ul.tabs:after,
		.calendar_wrap tbody tr:first-child,
		.calendar_wrap tbody tr:last-child,
		tfoot,
		tfoot tr td,
		.author-info,
		.wpcf7 div input,
		.wpcf7 div textarea,
		#promotion-section .play-button,
		.woocommerce-shorting-wrapper,
		.woocommerce-tabs ul.tabs.wc-tabs li,
		.menu-wrapper .widget_shopping_cart ul.woocommerce-mini-cart li,
		.entry-summary form.cart,
		.widget_recent_entries li,
		.team-section .team-content-wrapper .hentry .team-social-profile .social-links-menu,
		table,
		caption,
		table th,
		table thead tr,
		table thead th,
		thead th,
		tbody th,
		tbody td,
		tbody tr,
		table.shop_table_responsive tr td,
		table tbody tr,
		table.shop_table_responsive tbody tr:last-child,
		tr:last-child th,
		tr:last-child td,
		.shop_table tfoot tr td,
		.shop_table tfoot tr th,
		table.shop_table.woocommerce-checkout-review-order-table .cart_item td,
		table.shop_table.woocommerce-checkout-review-order-table tr td,
		table.shop_table.woocommerce-checkout-review-order-table tr th,
		.rtl tbody td:last-child,
		.rtl table thead th:last-child,
		.select2-container--default .select2-selection--single,
		table.woocommerce-grouped-product-list.group_table,
		table.woocommerce-grouped-product-list.group_table td,
		table.variations,
		table.variations td,
		.woocommerce-posts-wrapper .summary.entry-summary .woocommerce-product-rating,
		.cart-collaterals .order-total,
		#payment .wc_payment_methods .payment_box,
		.products .product,
		select,
		header .site-header-main,
		abbr,
		acronym,
		.product-quantity input[type="number"],
		.coupon input[type="text"],
		.catch-instagram-feed-gallery-widget-wrapper .button,
		.site-header-cart .widget_shopping_cart,
		.woocommerce-grouped-product-list tr,
		.mobile-social-search,
		.widget .ui-tabs .ui-tabs-panel,
		.site-header-menu .menu-inside-wrapper .nav-menu button:focus,
		header .site-header-menu .menu-inside-wrapper .main-navigation .sub-menu li:last-child,
		header .site-header-menu .menu-inside-wrapper .main-navigation .children li:last-child,
		.comment-body,
		.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link,
		.section:nth-child(2n) + .site-content,
		.archive-content-wrap .section-content-wrapper.layout-one .hentry .hentry-inner .entry-container>.entry-meta,
		.playlist-content-wrapper .wp-playlist .wp-playlist-tracks,
		.content-area .post-navigation .nav-previous,
		.content-area .post-navigation .nav-next,
		.page .site-main .entry-footer .entry-meta > span:not(.edit-link),
		.single .site-main .entry-footer .entry-meta > span:not(.edit-link),
		.events-content-wrapper .hentry,
		.tagcloud a,
		textarea:focus,
		input[type="text"]:focus,
		input[type="email"]:focus,
		input[type="url"]:focus,
		input[type="password"]:focus,
		input[type="search"]:focus,
		input[type="number"]:focus,
		input[type="tel"]:focus,
		input[type="range"]:focus,
		input[type="date"]:focus,
		input[type="month"]:focus,
		input[type="week"]:focus,
		input[type="time"]:focus,
		input[type="datetime"]:focus,
		input[type="datetime-local"]:focus,
		input[type="color"]:focus,
		.wpcf7 div input:focus,
		.wpcf7 div textarea:focus,
		#site-header-menu,
		#content #infinite-handle > span > button:hover,
		#content #infinite-handle > span > button:focus,
		.site-footer-menu .wrapper > #social-footer-navigation,
		.archive-posts-wrapper .layout-one .hentry .hentry-inner,
		.navigation-classic .main-navigation ul ul,
		.top-navigation ul ul,
		#hero-section.section .more-link:hover,
		#hero-section.section .more-link:focus,
		#hero-section.section .button:hover,
		#hero-section.section .button:focus,
		.timeline-section.section .more-link:hover,
		.timeline-section.section .more-link:focus,
		.timeline-section.section .button:hover,
		.timeline-section.section .button:focus,
		#events-section.section .more-link:hover,
		#events-section.section .more-link:focus,
		#events-section.section .button:hover,
		#events-section.section .button:focus,
		.team-section .more-link:hover,
		.team-section .more-link:focus,
		.team-section .button:hover,
		.team-section .button:focus,
		.promotion-section .more-link:hover,
		.promotion-section .more-link:focus,
		.promotion-section .button:hover,
		.promotion-section .button:focus,
		.entry-content .button:hover,
		.entry-summary .button:focus,
		.view-more .button:hover,
		.view-more .button:focus,
		.view-more .more-link:hover,
		.view-more .more-link:focus,
		.entry-content button:hover,
		.entry-summary button:hover,
		#site-header-cart .woocommerce-mini-cart__buttons a:hover,
		#site-header-cart .woocommerce-mini-cart__buttons a:focus,
		.site-content .archive-posts-wrapper .posts-navigation .nav-links > div a:hover,
		.site-content .archive-posts-wrapper .posts-navigation .nav-links > div a:focus,
		tbody tr:last-child th,
		tbody tr:last-child td,
		#site-generator #social-footer-navigation a:before,
		#primary-menu-wrapper #site-header-cart-wrapper,
		.site-header-top-main,
		.site-content + .recent-blog-content-wrapper {
			border-color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $border_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_border_color_css', 11 );

/**
 * Enqueues front-end CSS for Text color with background image
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_textcolor_with_background_css() {
	$color_scheme              = signify_get_color_scheme();
	$default_color             = $color_scheme[18];
	$textcolor_with_background = get_theme_mod( 'textcolor_with_background', $default_color );

	// Don't do anything if the current color is the default.
	if ( $textcolor_with_background === $default_color ) {
		return;
	}

	$css = '
		/* Text color with background color */
		.scroll-down,
		.custom-header .entry-breadcrumbs a,
		.woocommerce .custom-header .woocommerce-breadcrumb a,
		.has-header-image .custom-header .catch-breadcrumb .entry-breadcrumbs,
		.has-header-image .custom-header .catch-breadcrumb .woocommerce-breadcrumb,
		.custom-header-content .entry-title .sub-title,
		.hero-content-wrapper.has-background-image .entry-container,
		.custom-header-content .entry-container,
		.custom-header-content .entry-container .entry-title,
		.ewnewsletter.has-background-image .section-title,
		.testimonials-content-wrapper.section.testimonial-wrapper.has-background-image .hentry,
		.testimonials-content-wrapper.section.testimonial-wrapper.has-background-image .position,
		.slider-content-wrapper.content-frame .entry-container .entry-title a,
		.slider-content-wrapper.content-frame .entry-container .entry-container-wrap .entry-summary,
		.has-background-image .section-title,
		.has-background-image  .entry-container .entry-meta a,
		.has-background-image  .entry-container .entry-title a,
		.has-background-image  .entry-container .entry-title,
		.has-background-image  .entry-container .entry-title span,
		.has-background-image  .entry-container .entry-summary,
		.has-background-image  .entry-container .entry-content,
		.has-background-image .woocommerce-loop-product__title,
		.content-color-white .entry-container .entry-title a,
		.content-color-white .entry-container .entry-title,
		.content-color-white .entry-container .entry-content,
		.content-color-white .entry-container .entry-summary,
		.content-color-white .section-description,
		#promotion-section .play-button,
		.has-background-image .products .button,
		.playlist-content-wrapper .wp-playlist-caption,
		#service-section.has-background-image .hentry .more-link,
		#stats-section.has-background-image .hentry .more-link,
		.play-button-text,
		.sticky-post,
		.gallery-caption,
		.has-background-image .event-list-description .entry-summary,
		.has-background-image .event-list-description .entry-content ,
		#contact-section.has-background-image .entry-content,
		#contact-section.has-background-image .entry-summary,
		.playlist-content-wrapper .wp-playlist-tracks,
		#contact-section .entry-container .entry-content .contact-details label,
		#contact-section .entry-container .entry-summary .contact-details label,
		.has-background-image .section-description-wrapper,
		.has-background-image .section-title-wrapper+.section-description,
		.has-background-image .section-title+.section-description,
		.has-background-image .section-title-wrapper+.section-subtitle,
		.has-background-image .section-heading-wrapper>.section-description,
		.has-background-image .section-title+.section-description,
		.has-background-image .section-heading-wrapper>.section-subtitle,
		#playlist-section .signify-mejs-container.mejs-container button {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $textcolor_with_background ) );
}
add_action( 'wp_enqueue_scripts', 'signify_textcolor_with_background_css', 11 );

/**
 * Enqueues front-end CSS for the Contact and Newsletter background color
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */

/**
 * Converts a HEX value to RGB.
 *
 * @since 1.0.0
 *
 * @param string $color The original color, in 3- or 6-digit hexadecimal form.
 * @return array Array containing RGB (red, green, and blue) values for the given
 *               HEX code, empty array otherwise.
 */
function signify_hex2rgb( $color ) {
	$color = trim( $color, '#' );

	if ( strlen( $color ) === 3 ) {
		$r = hexdec( substr( $color, 0, 1 ).substr( $color, 0, 1 ) );
		$g = hexdec( substr( $color, 1, 1 ).substr( $color, 1, 1 ) );
		$b = hexdec( substr( $color, 2, 1 ).substr( $color, 2, 1 ) );
	} else if ( strlen( $color ) === 6 ) {
		$r = hexdec( substr( $color, 0, 2 ) );
		$g = hexdec( substr( $color, 2, 2 ) );
		$b = hexdec( substr( $color, 4, 2 ) );
	} else {
		return array();
	}

	return array( 'red' => $r, 'green' => $g, 'blue' => $b );
}
